SystemOrganization addCategory: #'Xpf-Client-Tests'!
SystemOrganization addCategory: #'Xpf-Client-Morphs'!
SystemOrganization addCategory: #'Xpf-Client-Helpers'!
SystemOrganization addCategory: #'Xpf-Client-AdminTool'!
SystemOrganization addCategory: #'Xpf-Client-Models'!

PluggableDialogWindow subclass: #XpfDialog
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

XpfDialog subclass: #XpfAdminTool
	instanceVariableNames: 'projectList userList projectTitleEntry userNameEntry userLoginEntry saveProjectButton saveUserButton projectAddButton userAddButton projectDeleteButton userDeleteButton userPasswordButton projectDeveloperList projectUserDropList projectAddDeveloperButton projectDeleteDeveloperButton'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-AdminTool'!

!XpfAdminTool class methodsFor: 'user interface' stamp: 'cs 3/18/2009 11:05'!
open
	| instance connectionString factory response |
	instance := self new.
	connectionString := (instance openModal: XpfLogin new) result.
	connectionString ifNil: [^ self].
	[response := RestSocket get: connectionString] on: ConnectionTimedOut
		do: 
			[:e | 
			UITheme current 
				alertIn: instance
				text: e messageText
				title: 'Connection timed out'.
			^ self].
	response responseCode = 401 
		ifTrue: 
			[UITheme current 
				alertIn: instance
				text: 'You are not authorized to access any resource on the server.'
				title: 'Connection failed'.
			^ self].
	factory := XpfProxyRepository fromString: connectionString.
	^ (instance initializeWith: factory) openInWorld! !

!XpfAdminTool methodsFor: 'user interface' stamp: 'mt 3/5/2009 10:21'!
createProjectAddButtonFor: myModel 

	self projectAddButton: (UITheme current 
		newButtonIn: self
		for: myModel
		getState: nil
		action: #addProject
		arguments: nil
		getEnabled: nil
		label: 'Add Project'
		help: 'Add new project').
	^ self projectAddButton! !

!XpfAdminTool methodsFor: 'user interface' stamp: 'mt 3/6/2009 16:37'!
createProjectAddDeveloperButtonFor: myModel 

	self projectAddDeveloperButton: (UITheme current 
		newButtonIn: self
		for: myModel
		getState: nil
		action: #addDeveloperToProject
		arguments: nil
		getEnabled: #hasCurrentProjectCandidateIndex
		label: 'Add'
		help: 'Add the candidate as developer to this project.').
	^ self projectAddDeveloperButton! !

!XpfAdminTool methodsFor: 'user interface' stamp: 'mt 3/5/2009 13:15'!
createProjectDeleteButtonFor: myModel 

	self projectDeleteButton: (UITheme current 
		newButtonIn: self
		for: myModel
		getState: nil
		action: #deleteProject
		arguments: nil
		getEnabled: #hasProjects
		label: 'Delete Project'
		help: 'Delete project').
	^ self projectDeleteButton! !

!XpfAdminTool methodsFor: 'user interface' stamp: 'cs 3/9/2009 15:29'!
createProjectDeleteDeveloperButtonFor: myModel 

	self projectDeleteDeveloperButton: (UITheme current 
		newButtonIn: self
		for: myModel
		getState: nil
		action: #deleteDeveloper
		arguments: nil
		getEnabled: #hasCurrentProjectDeveloperIndex
		label: 'Remove'
		help: 'Remove the selected developer from the current project. The user remains in the database.').
	^ self projectDeleteDeveloperButton! !

!XpfAdminTool methodsFor: 'user interface' stamp: 'mt 3/6/2009 15:48'!
createProjectDeveloperListFor: aModel

	self projectDeveloperList: (UITheme current
		newListIn: self
		for: aModel
		list: #allProjectDeveloperNames
		selected: #currentProjectDeveloperIndex
		changeSelected: #currentProjectDeveloperIndex:
		getEnabled: nil
		help: 'Shows all developers of this project.').
	^ self projectDeveloperList minHeight: 150! !

!XpfAdminTool methodsFor: 'user interface' stamp: 'mt 3/5/2009 14:21'!
createProjectListFor: aModel

	self projectList: (UITheme current
		newListIn: self
		for: aModel
		list: #allProjectTitles
		selected: #currentProjectIndex
		changeSelected: #currentProjectIndex:
		getEnabled: nil
		help: 'Shows all projects.').
	^ self projectList minHeight: 150! !

!XpfAdminTool methodsFor: 'user interface' stamp: 'mt 3/5/2009 14:20'!
createProjectTitleEntryFor: myModel

	self projectTitleEntry: ((UITheme current 
		newTextEntryIn: self
		for: myModel
		get: #currentProjectTitle
		set: #currentProjectTitle:
		class: String
		getEnabled: #hasCurrentProject
		help: 'Enter a short descriptive title for this project.') maxLength: 100).
	^ self projectTitleEntry minWidth: 200! !

!XpfAdminTool methodsFor: 'user interface' stamp: 'mt 3/6/2009 15:49'!
createProjectUserDropListFor: aModel

	self projectUserDropList: (UITheme current
		newDropListIn: self
		for: aModel
		list: #allProjectCandidateNames
		getSelected: #currentProjectCandidateIndex
		setSelected: #currentProjectCandidateIndex:
		getEnabled: #hasCurrentProjectCandidates
		useIndex: true
		help: 'All available users for this project').
	^ self projectUserDropList! !

!XpfAdminTool methodsFor: 'user interface' stamp: 'cs 3/9/2009 15:39'!
createProjectsTabFor: myModel 

	| col row |
	col := self createCol: { 
		self createRow: {self createLabel: 'Title:'. self createProjectTitleEntryFor: myModel}.
		self createRow: {self createHFiller. self createSaveProjectButton}.
		self createHSeparator.
		self createRow: {
			self createLabel: 'Developers:'.
			self createHFiller.
			self createProjectDeleteDeveloperButtonFor: myModel}.
		self createProjectDeveloperListFor: myModel.
		self createRow: {
			self createLabel: 'Candidate:'. 
			self createProjectUserDropListFor: myModel. 
			self createProjectAddDeveloperButtonFor: myModel}}.
		
	row := self createRow: {
		self createCol: {
			self createProjectListFor: myModel. 
			self createRow: {
				self createProjectAddButtonFor: myModel. 
				self createProjectDeleteButtonFor: myModel. 
				self createHFiller}}.
		self createVSeparator.
		col}.
	row vResizing: #spaceFill.
	^ row! !

!XpfAdminTool methodsFor: 'user interface' stamp: 'mig 3/13/2009 16:02'!
createQuitButton

	^ UITheme current 
		newButtonIn: self
		for: self
		getState: nil
		action: #cancel
		arguments: nil
		getEnabled: nil
		label: 'Quit'
		help: 'Close the admin tool'! !

!XpfAdminTool methodsFor: 'user interface' stamp: 'mt 3/5/2009 13:30'!
createSaveProjectButton

	self saveProjectButton: (UITheme current 
		newButtonIn: self
		for: self projectTitleEntry
		getState: nil
		action: #accept
		arguments: nil
		getEnabled: #enabled
		label: 'Save'
		help: 'Save changed project title').
	^ self saveProjectButton! !

!XpfAdminTool methodsFor: 'user interface' stamp: 'mt 3/5/2009 14:35'!
createSaveUserButtonFor: myModel

	self saveUserButton: (UITheme current 
		newButtonIn: self
		for: myModel
		getState: nil
		action: #updateUser:
		arguments: {{self userNameEntry. self userLoginEntry}}
		getEnabled: #hasCurrentUser
		label: 'Save'
		help: 'Save changed user data').
	^ self saveUserButton! !

!XpfAdminTool methodsFor: 'user interface' stamp: 'mt 3/5/2009 11:00'!
createUserAddButtonFor: myModel 

	self userAddButton: (UITheme current 
		newButtonIn: self
		for: myModel
		getState: nil
		action: #addUser
		arguments: nil
		getEnabled: nil
		label: 'Add User'
		help: 'Add new user').
	^ self userAddButton! !

!XpfAdminTool methodsFor: 'user interface' stamp: 'mt 3/5/2009 14:05'!
createUserDeleteButtonFor: myModel 

	self userDeleteButton: (UITheme current 
		newButtonIn: self
		for: myModel
		getState: nil
		action: #deleteUser
		arguments: nil
		getEnabled: #hasUsers
		label: 'Delete User'
		help: 'Delete User').
	^ self userDeleteButton! !

!XpfAdminTool methodsFor: 'user interface' stamp: 'mt 3/5/2009 14:23'!
createUserListFor: aModel

	self userList: (UITheme current
		newListIn: self
		for: aModel
		list: #allUserNames
		selected: #currentUserIndex
		changeSelected: #currentUserIndex:
		getEnabled: nil
		help: 'Shows all users.').
	^ self userList minHeight: 150! !

!XpfAdminTool methodsFor: 'user interface' stamp: 'mt 3/5/2009 14:03'!
createUserLoginEntryFor: myModel

	self userLoginEntry: ((UITheme current 
		newTextEntryIn: self
		for: myModel
		get: #currentUserLogin
		set: #currentUserLogin:
		class: String
		getEnabled: #hasCurrentUser
		help: 'Enter a valid email address') maxLength: 100).
	^ self userLoginEntry! !

!XpfAdminTool methodsFor: 'user interface' stamp: 'mt 3/5/2009 14:23'!
createUserNameEntryFor: myModel

	self userNameEntry: ((UITheme current 
		newTextEntryIn: self
		for: myModel
		get: #currentUserName
		set: #currentUserName:
		class: String
		getEnabled: #hasCurrentUser
		help: 'Enter the name of the user.') maxLength: 100).
	^ self userNameEntry minWidth: 200! !

!XpfAdminTool methodsFor: 'user interface' stamp: 'mt 3/6/2009 13:35'!
createUserPasswordButtonFor: myModel 

	self userPasswordButton: (UITheme current 
		newButtonIn: self
		for: myModel
		getState: nil
		action: #changePassword:
		arguments: {self}
		getEnabled: #hasCurrentUser
		label: 'Change Password...'
		help: 'Change the current password').
	^ self userPasswordButton! !

!XpfAdminTool methodsFor: 'user interface' stamp: 'mt 3/6/2009 13:36'!
createUsersTabFor: myModel

	| col row |
	col := self createCol: { 
		self createRow: {
			self createLabel: 'Name:'. 
			self createUserNameEntryFor: myModel}.
		self createRow: {
			self createLabel: 'Login/E-Mail:'. 
			self createUserLoginEntryFor: myModel}.
		self createRow: {
			self createUserPasswordButtonFor: myModel.
			self createHFiller. 
			self createSaveUserButtonFor: myModel}}.
		
	row := self createRow: {
		self createCol: {
			self createUserListFor: myModel. 
			self createRow: {
				self createUserAddButtonFor: myModel. 
				self createUserDeleteButtonFor: myModel. 
				self createHFiller}}.
		self createVSeparator.
		col}.
	
	row vResizing: #spaceFill.
	^ row! !

!XpfAdminTool methodsFor: 'initialization' stamp: 'mt 3/6/2009 14:26'!
initializeUserInterface: myModel

	^ UITheme current
		newTabGroupIn: self for: {
			'Projects' -> (self createProjectsTabFor: myModel). 
			'Users' -> (self createUsersTabFor: myModel)}! !

!XpfAdminTool methodsFor: 'initialization' stamp: 'mt 3/16/2009 11:25'!
initializeWith: aRepository 
	| myModel |
	myModel := XpfAdminToolModel newWithRepository: aRepository.
	self
		buttons: {  (self createQuitButton)};
		contentMorph: (self initializeUserInterface: myModel);
		model: myModel;
		addGrips;
		title: 'Project Management'! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/5/2009 09:46'!
projectAddButton
	^ projectAddButton! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/5/2009 09:46'!
projectAddButton: anObject
	projectAddButton := anObject! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/6/2009 15:01'!
projectAddDeveloperButton
	^ projectAddDeveloperButton! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/6/2009 15:01'!
projectAddDeveloperButton: anObject
	projectAddDeveloperButton := anObject! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/5/2009 11:36'!
projectDeleteButton
	^ projectDeleteButton! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/5/2009 11:36'!
projectDeleteButton: anObject
	projectDeleteButton := anObject! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'cs 3/9/2009 15:25'!
projectDeleteDeveloperButton
	
	^ projectDeleteDeveloperButton! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'cs 3/9/2009 15:24'!
projectDeleteDeveloperButton: anObject

	projectDeleteDeveloperButton := anObject.! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/6/2009 15:01'!
projectDeveloperList
	^ projectDeveloperList! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/6/2009 15:01'!
projectDeveloperList: anObject
	projectDeveloperList := anObject! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'topa 3/4/2009 00:00'!
projectList

	^ projectList! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'topa 3/4/2009 00:00'!
projectList: anObject

	projectList := anObject.! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/4/2009 13:05'!
projectTitleEntry
	^ projectTitleEntry! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/4/2009 13:05'!
projectTitleEntry: anObject
	projectTitleEntry := anObject! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/6/2009 15:01'!
projectUserDropList
	^ projectUserDropList! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/6/2009 15:01'!
projectUserDropList: anObject
	projectUserDropList := anObject! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/4/2009 13:31'!
saveProjectButton
	^ saveProjectButton! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/4/2009 13:31'!
saveProjectButton: anObject
	saveProjectButton := anObject! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/4/2009 13:31'!
saveUserButton
	^ saveUserButton! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/4/2009 13:31'!
saveUserButton: anObject
	saveUserButton := anObject! !

!XpfAdminTool methodsFor: 'updating' stamp: 'mt 3/4/2009 14:45'!
updateUser
	"Accepts all user-data-specific controls to force update of model."
	
	self userNameEntry accept.
	self userLoginEntry accept.! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/5/2009 11:02'!
userAddButton
	^ userAddButton! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/5/2009 11:02'!
userAddButton: anObject
	userAddButton := anObject! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/5/2009 13:48'!
userDeleteButton
	^ userDeleteButton! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/5/2009 13:48'!
userDeleteButton: anObject
	userDeleteButton := anObject! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/4/2009 12:57'!
userList
	^ userList! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/4/2009 12:57'!
userList: anObject
	userList := anObject! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/4/2009 14:44'!
userLoginEntry
	^ userLoginEntry! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/4/2009 14:44'!
userLoginEntry: anObject
	userLoginEntry := anObject! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/4/2009 13:30'!
userNameEntry
	^ userNameEntry! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/4/2009 13:30'!
userNameEntry: anObject
	userNameEntry := anObject! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/6/2009 13:32'!
userPasswordButton
	^ userPasswordButton! !

!XpfAdminTool methodsFor: 'accessing' stamp: 'mt 3/6/2009 13:32'!
userPasswordButton: anObject
	userPasswordButton := anObject! !

!XpfDialog methodsFor: 'user interface helper' stamp: 'mt 3/6/2009 10:25'!
createCol: someElements

	^ UITheme current newColumnIn: self for: someElements! !

!XpfDialog methodsFor: 'user interface helper' stamp: 'mt 3/6/2009 10:25'!
createHFiller

	^ (UITheme current newToolSpacerIn: self) hResizing: #spaceFill! !

!XpfDialog methodsFor: 'user interface helper' stamp: 'mt 3/6/2009 10:26'!
createHSeparator

	^ UITheme current newSeparatorIn: self! !

!XpfDialog methodsFor: 'user interface helper' stamp: 'mt 3/6/2009 10:26'!
createLabel: aString

	^ UITheme current
		newLabelIn: self
		label: aString! !

!XpfDialog methodsFor: 'user interface helper' stamp: 'mt 3/6/2009 10:26'!
createRow: someElements

	^ UITheme current newRowIn: self for: someElements! !

!XpfDialog methodsFor: 'user interface helper' stamp: 'mt 3/6/2009 10:26'!
createVFiller

	^ (UITheme current newToolSpacerIn: self) vResizing: #spaceFill! !

!XpfDialog methodsFor: 'user interface helper' stamp: 'mt 3/6/2009 10:26'!
createVSeparator

	^ (UITheme current newSeparatorIn: self) hResizing: #rigid; vResizing: #spaceFill! !

!XpfDialog methodsFor: 'initialization' stamp: 'topa 3/6/2009 14:53'!
initializeUserInterface: aModel

	self subclassResponsibility.! !

XpfDialog subclass: #XpfLogin
	instanceVariableNames: 'loginEntry passwordEntry connectButton cancelButton result urlEntry'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfLogin methodsFor: 'accessing' stamp: 'topa 3/6/2009 14:50'!
cancelButton

	^ cancelButton! !

!XpfLogin methodsFor: 'accessing' stamp: 'topa 3/6/2009 14:50'!
cancelButton: anObject

	cancelButton := anObject.! !

!XpfLogin methodsFor: 'accessing' stamp: 'topa 3/6/2009 14:50'!
connectButton

	^ connectButton! !

!XpfLogin methodsFor: 'accessing' stamp: 'topa 3/6/2009 14:50'!
connectButton: anObject

	connectButton := anObject.! !

!XpfLogin methodsFor: 'user interface' stamp: 'mt 3/6/2009 10:47'!
createCancelButton 

	self cancelButton: (UITheme current 
		newButtonIn: self
		for: self
		getState: nil
		action: #cancel
		arguments: nil
		getEnabled: nil
		label: 'Cancel'
		help: 'Close login window').
	^ self cancelButton! !

!XpfLogin methodsFor: 'user interface' stamp: 'mt 3/6/2009 10:46'!
createConnectButton 

	self connectButton: (UITheme current 
		newButtonIn: self
		for: self
		getState: nil
		action: #ok
		arguments: nil
		getEnabled: nil
		label: 'Connect'
		help: 'Try to connect to server').
	^ self connectButton! !

!XpfLogin methodsFor: 'user interface' stamp: 'topa 3/6/2009 14:51'!
createLoginEntryFor: myModel

	self loginEntry: ((UITheme current 
		newTextEntryIn: self
		for: myModel
		get: #login
		set: #login:
		class: String
		getEnabled: nil
		help: 'Enter login') maxLength: 100).
	^ self loginEntry! !

!XpfLogin methodsFor: 'user interface' stamp: 'topa 3/6/2009 14:51'!
createPasswordEntryFor: myModel

	self passwordEntry: ((UITheme current 
		newTextEntryIn: self
		for: myModel
		get: #password
		set: #password:
		class: String
		getEnabled: nil
		help: 'Enter password') maxLength: 100).
	self passwordEntry textMorph font: (StrikeFont passwordFontSize: 12).
	^ self passwordEntry! !

!XpfLogin methodsFor: 'user interface' stamp: 'SR 3/10/2009 17:33'!
createURLEntryFor: myModel

	self urlEntry: ((UITheme current 
		newTextEntryIn: self
		for: myModel
		get: #url
		set: #url:
		class: String
		getEnabled: nil
		help: 'Enter the url of the server.') maxLength: 100).
	^ self urlEntry minWidth: 200! !

!XpfLogin methodsFor: 'initialization' stamp: 'topa 3/6/2009 17:55'!
initialize

	| myModel |
	super initialize.
	
	myModel := XpfLoginModel new.
	self
		buttons: {self createConnectButton. self createCancelButton};
		contentMorph: (self initializeUserInterface: myModel);
		model: myModel;
		addGrips;
		title: 'Login'.! !

!XpfLogin methodsFor: 'initialization' stamp: 'SR 3/10/2009 17:27'!
initializeUserInterface: myModel

	^ self createCol: {
		self createRow: {
			self createLabel: 'URL:'.
			self createURLEntryFor: myModel.}.
		self createHSeparator.
		self createRow: {
			self createLabel: 'Login:'.
			self createLoginEntryFor: myModel}.
		self createRow: {
			self createLabel: 'Password:'.
			self createPasswordEntryFor: myModel}}! !

!XpfLogin methodsFor: 'accessing' stamp: 'topa 3/6/2009 14:51'!
loginEntry

	^ loginEntry! !

!XpfLogin methodsFor: 'accessing' stamp: 'topa 3/6/2009 14:51'!
loginEntry: anObject

	loginEntry := anObject! !

!XpfLogin methodsFor: 'initialization' stamp: 'SR 3/10/2009 17:47'!
ok

	self urlEntry accept.
	self loginEntry accept.
	self passwordEntry accept.
			
	self result: self model connectString.
	^ super ok! !

!XpfLogin methodsFor: 'accessing' stamp: 'topa 3/6/2009 14:52'!
passwordEntry

	^ passwordEntry! !

!XpfLogin methodsFor: 'accessing' stamp: 'topa 3/6/2009 14:52'!
passwordEntry: anObject

	passwordEntry := anObject.! !

!XpfLogin methodsFor: 'accessing' stamp: 'topa 3/6/2009 14:52'!
result

	^ result! !

!XpfLogin methodsFor: 'accessing' stamp: 'topa 3/6/2009 14:52'!
result: anObject

	result := anObject.! !

!XpfLogin methodsFor: 'accessing' stamp: 'SR 3/10/2009 17:28'!
urlEntry

	^ urlEntry! !

!XpfLogin methodsFor: 'accessing' stamp: 'SR 3/10/2009 17:28'!
urlEntry: anObject

	urlEntry := anObject.! !

XpfDialog subclass: #XpfProjectChooser
	instanceVariableNames: 'okButton cancelButton projectDropList result'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfProjectChooser methodsFor: 'accessing' stamp: 'topa 3/6/2009 17:42'!
cancelButton

	^ cancelButton! !

!XpfProjectChooser methodsFor: 'accessing' stamp: 'topa 3/6/2009 17:42'!
cancelButton: anObject

	cancelButton := anObject.! !

!XpfProjectChooser methodsFor: 'user interface helper' stamp: 'topa 3/6/2009 17:48'!
createCancelButton 

	self cancelButton: (UITheme current 
		newButtonIn: self
		for: self
		getState: nil
		action: #cancel
		arguments: nil
		getEnabled: nil
		label: 'Cancel'
		help: 'Close window').
	^ self cancelButton! !

!XpfProjectChooser methodsFor: 'user interface helper' stamp: 'topa 3/6/2009 17:49'!
createOkButton 

	self okButton: (UITheme current 
		newButtonIn: self
		for: self
		getState: nil
		action: #ok
		arguments: nil
		getEnabled: nil
		label: 'Ok'
		help: 'Confirm Project Id').
	^ self okButton! !

!XpfProjectChooser methodsFor: 'user interface helper' stamp: 'SR 3/10/2009 14:01'!
createProjectDropList: myModel

	self projectDropList: (UITheme current 
		newDropListIn: self
		for: myModel projectsModel
		list: #list
		getSelected: #selectionIndex
		setSelected: #selectionIndex:
		getEnabled: nil
		useIndex: true
		help: 'Enter project id').
	self projectDropList minWidth: 200.
	^ self projectDropList! !

!XpfProjectChooser methodsFor: 'initialization' stamp: 'SR 3/10/2009 13:53'!
initialize

	| myModel |
	super initialize.
	
	myModel := XpfProjectChooserModel new.
	
	self
		buttons: {self createOkButton. self createCancelButton};
		contentMorph: (self initializeUserInterface: myModel);
		model: myModel;
		addGrips;
		title: 'Specify Project'.! !

!XpfProjectChooser methodsFor: 'initialization' stamp: 'SR 3/10/2009 13:54'!
initializeUserInterface: myModel

	^ self createCol: {
		self createRow: {
			self createLabel: 'Project:'.	self createProjectDropList: myModel}}! !

!XpfProjectChooser methodsFor: 'actions' stamp: 'SR 3/10/2009 14:00'!
ok

	self result: self model project.
	
	^ super ok! !

!XpfProjectChooser methodsFor: 'accessing' stamp: 'topa 3/6/2009 17:42'!
okButton

	^ okButton! !

!XpfProjectChooser methodsFor: 'accessing' stamp: 'topa 3/6/2009 17:42'!
okButton: anObject

	okButton := anObject.! !

!XpfProjectChooser methodsFor: 'accessing' stamp: 'SR 3/10/2009 13:49'!
projectDropList

	^ projectDropList! !

!XpfProjectChooser methodsFor: 'accessing' stamp: 'SR 3/10/2009 13:49'!
projectDropList: anObject

	projectDropList := anObject.! !

!XpfProjectChooser methodsFor: 'accessing' stamp: 'topa 3/6/2009 17:46'!
result

	^ result! !

!XpfProjectChooser methodsFor: 'accessing' stamp: 'topa 3/6/2009 17:46'!
result: anObject

	result := anObject.! !

ScrollPane subclass: #XpfTaskListMorph
	instanceVariableNames: 'content userStory'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfTaskListMorph class methodsFor: 'as yet unclassified' stamp: 'mt 3/13/2009 15:22'!
forUserStory: anXpfUserStory

	^ self new userStory: anXpfUserStory! !

!XpfTaskListMorph methodsFor: 'as yet unclassified' stamp: 'mt 3/13/2009 16:18'!
addTaskMorph: aTaskMorph

	self content addMorph: aTaskMorph.
	self content height: ((self content submorphs size) * (aTaskMorph height + (self content cellInset * 2))).
	
	! !

!XpfTaskListMorph methodsFor: 'accessing' stamp: 'mt 3/13/2009 11:37'!
content

	content ifNil: [content := PasteUpMorph new color: Color transparent].
	^ content! !

!XpfTaskListMorph methodsFor: 'accessing' stamp: 'mt 3/13/2009 11:21'!
content: anObject
	content := anObject! !

!XpfTaskListMorph methodsFor: 'as yet unclassified' stamp: 'mt 3/13/2009 15:13'!
initialize

	super initialize.
	self
		useRoundedCorners;
		hResizing: #spaceFill;
		vResizing: #spaceFill;
		spaceFillWeight: 1;
		fillStyle: Color veryVeryLightGray;
		borderWidth: 0;
		alwaysShowHScrollBar: false;
		alwaysShowVScrollBar: true;
		color: Color transparent.
	
	self scroller addMorph: self content.
	
	self content
		layoutPolicy: TableLayout new;
		hResizing: #rigid;
		vResizing: #rigid;
		cellInset: 5;
		layoutInset: 5;
		borderWidth: 0.! !

!XpfTaskListMorph methodsFor: 'as yet unclassified' stamp: 'mt 3/13/2009 12:00'!
layoutChanged

	super layoutChanged.
	self content width: self width - 14 - 10. self flag: #TODO. "Find out how to get the width of the vertical scrollbar"! !

!XpfTaskListMorph methodsFor: 'as yet unclassified' stamp: 'mt 3/13/2009 15:27'!
updateList

	self content removeAllMorphs.
	self userStory tasks do: [:task | self addTaskMorph: (XpfTaskMorph forTask: task)].! !

!XpfTaskListMorph methodsFor: 'accessing' stamp: 'mt 3/13/2009 15:17'!
userStory
	^ userStory! !

!XpfTaskListMorph methodsFor: 'accessing' stamp: 'mt 3/13/2009 15:24'!
userStory: anObject

	userStory := anObject.
	self updateList.! !

PasteUpMorph subclass: #XpfUserStoryPoolMorph
	instanceVariableNames: 'userStoryAddMorph userStoryDeleteMorph'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfUserStoryPoolMorph class methodsFor: 'contants' stamp: 'cs 3/18/2009 17:05'!
defaultGridSize

	^ 32@32! !

!XpfUserStoryPoolMorph class methodsFor: 'instance creation' stamp: 'cs 3/11/2009 17:33'!
forUserStories: anXpfUserStoryCollection

	^ self new model: anXpfUserStoryCollection! !

!XpfUserStoryPoolMorph methodsFor: 'as yet unclassified' stamp: 'cs 3/18/2009 17:25'!
acceptDroppingMorph: aMorph event: evt 
	
	aMorph position: (self gridPoint: aMorph position).
		
	aMorph model positionX: (aMorph left - self left) / (self width - aMorph width) asFloat.
	aMorph model positionY: (aMorph top - self top) / (self height - aMorph height) asFloat.
	super acceptDroppingMorph: aMorph event: evt.! !

!XpfUserStoryPoolMorph methodsFor: 'testing' stamp: 'cs 3/10/2009 16:14'!
acceptsUserStories

	^ true! !

!XpfUserStoryPoolMorph methodsFor: 'accessing' stamp: 'cs 3/11/2009 15:44'!
addUserStoryMorph: anXpfUserStoryMorph

	^ self addMorph:
		"Places new UserStories in the top left corner with 5 indent"
		(anXpfUserStoryMorph topLeft: self topLeft + (self submorphCount + 1 * 5 asPoint))! !

!XpfUserStoryPoolMorph methodsFor: 'initialization' stamp: 'cs 3/11/2009 17:57'!
buildUserStoryAddMorph
	
	self 
		userStoryAddMorph: 
			(XpfUserStoryAddMorph new
				topRight: XpfClient defaultWidth@5 + self topLeft);
		addMorph: self userStoryAddMorph.! !

!XpfUserStoryPoolMorph methodsFor: 'initialization' stamp: 'cs 3/11/2009 18:18'!
buildUserStoryDeleteMorph
	
	self 
		userStoryDeleteMorph: 
			((XpfUserStoryDeleteMorph forUserStories: self model)
				bottomLeft: 4@XpfClient defaultHeight + self topLeft);
		addMorph: self userStoryDeleteMorph.! !

!XpfUserStoryPoolMorph methodsFor: 'initialization' stamp: 'mfp 3/17/2009 15:49'!
buildUserStorySubmorphs

	self model do: [ :userStory| 
		self addUserStoryMorph: 
			(XpfUserStoryMorph forUserStory: userStory)]! !

!XpfUserStoryPoolMorph methodsFor: 'initialization' stamp: 'cs 3/18/2009 17:27'!
initialize

	super initialize.
	self
		borderWidth: 0;
		useRoundedCorners;
		color: Color veryVeryLightGray;
		hResizing: #spaceFill;
		vResizing: #spaceFill;
		buildUserStoryDeleteMorph;
		enableDragNDrop;
		gridModulus: self class defaultGridSize;
		griddingOnOff.! !

!XpfUserStoryPoolMorph methodsFor: 'as yet unclassified' stamp: 'mfp 3/18/2009 18:29'!
layoutChanged

	super layoutChanged.

	self userStorySubmorphs do: [:morph |  
		morph left: (morph model positionX * (self width - morph width)) + self left.
		morph top: (morph model positionY * (self height - morph height)) + self top].

	self userStoryDeleteMorph ifNotNil: [
		self userStoryDeleteMorph
			left: self left + 5;
			top: self top + self height - self userStoryDeleteMorph height - 5].

	self userStoryAddMorph ifNotNil: [
		self userStoryAddMorph
			left: self topCenter x - (self userStoryAddMorph width / 2);
			top: self top + 5].! !

!XpfUserStoryPoolMorph methodsFor: 'accessing' stamp: 'cs 3/11/2009 18:17'!
model: anXpfUserStoryCollection

	self removeAllMorphsIn: self userStorySubmorphs.
	self userStoryAddMorph ifNotNil: [self removeMorph: self userStoryAddMorph].
	self userStoryDeleteMorph ifNotNil: [self removeMorph: self userStoryDeleteMorph].
	model := anXpfUserStoryCollection.
	self
		buildUserStorySubmorphs;
		buildUserStoryAddMorph;
		buildUserStoryDeleteMorph.
	self model addDependent: self.! !

!XpfUserStoryPoolMorph methodsFor: 'as yet unclassified' stamp: 'SR 3/18/2009 11:58'!
saveUserStoryPosition

	self userStorySubmorphs do: [:morph | 
		morph model	positionX: (morph left - self left) / (self width - morph width) asFloat.
		morph model positionY: (morph top - self top) / (self height - morph height) asFloat.
	].! !

!XpfUserStoryPoolMorph methodsFor: 'accessing' stamp: 'topa 3/9/2009 15:34'!
userStoryAddMorph

	^ userStoryAddMorph! !

!XpfUserStoryPoolMorph methodsFor: 'accessing' stamp: 'topa 3/9/2009 15:42'!
userStoryAddMorph: anObject

	userStoryAddMorph := anObject.! !

!XpfUserStoryPoolMorph methodsFor: 'accessing' stamp: 'topa 3/11/2009 15:32'!
userStoryDeleteMorph

	^ userStoryDeleteMorph! !

!XpfUserStoryPoolMorph methodsFor: 'accessing' stamp: 'topa 3/11/2009 15:17'!
userStoryDeleteMorph: aMorph

	userStoryDeleteMorph := aMorph! !

!XpfUserStoryPoolMorph methodsFor: 'accessing' stamp: 'SR 2/23/2009 10:51'!
userStorySubmorphs

	^ self allMorphs select: [:aMorph| aMorph isUserStoryMorph]! !

!XpfUserStoryPoolMorph methodsFor: 'as yet unclassified' stamp: 'SR 3/18/2009 15:06'!
wantsDroppedMorph: aMorph event: evt
	^ aMorph isUserStoryMorph! !

PasteUpMorph subclass: #XpfUserStoryTimelineMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfUserStoryTimelineMorph class methodsFor: 'instance creation' stamp: 'cs 3/11/2009 15:16'!
forProject: anXpfProject

	| scrollPane |
	scrollPane := ScrollPane new.
	scrollPane
		useRoundedCorners;
		hResizing: #spaceFill;
		vResizing: #rigid;
		height: XpfUserStoryMorph defaultExtent y + 40;
		fillStyle: Color veryVeryLightGray;
		borderWidth: 0;
		alwaysShowHScrollBar: true;
		alwaysShowVScrollBar: false.
	scrollPane scroller addMorph: (self new model: anXpfProject).
	^ scrollPane! !

!XpfUserStoryTimelineMorph class methodsFor: 'instance creation' stamp: 'mfp 3/17/2009 15:48'!
newWithScrollBars

	| scrollPane |
	scrollPane := ScrollPane new.
	scrollPane
		useRoundedCorners;
		hResizing: #spaceFill;
		vResizing: #rigid;
		height: "XpfUserStoryMorph defaultExtent y" 100 + 40;
		fillStyle: Color veryVeryLightGray;
		borderWidth: 0;
		alwaysShowHScrollBar: true;
		alwaysShowVScrollBar: false.
	scrollPane scroller addMorph: self new.
	^ scrollPane! !

!XpfUserStoryTimelineMorph methodsFor: '*xpf-client' stamp: 'cs 3/10/2009 16:14'!
acceptsUserStories

	^ true! !

!XpfUserStoryTimelineMorph methodsFor: 'initialization' stamp: 'cs 3/11/2009 17:37'!
createUserInterface

	self model do: [:userStory |
		self addMorphBack: (XpfUserStoryMorph forUserStory: userStory)]! !

!XpfUserStoryTimelineMorph methodsFor: 'initialization' stamp: 'mfp 3/17/2009 15:49'!
initialize

	super initialize.
	self		
		changeTableLayout;
		hResizing: #shrinkWrap;
		vResizing: #rigid;
		fillStyle: Color veryVeryLightGray;
		minWidth: XpfClient defaultWidth - 40;
		borderWidth: 0;
		height: "XpfUserStoryMorph defaultExtent y" 100 + 16;
		listDirection: #leftToRight;
		layoutInset: 8;
		cellPositioning: #topLeft;
		cellInset: 16.! !

!XpfUserStoryTimelineMorph methodsFor: 'layout' stamp: 'cs 3/11/2009 13:15'!
layoutChanged

	self owner ifNotNil: 
		[self owner owner extent: 1@1 + self owner owner extent.
		self owner owner extent: -1@-1 + self owner owner extent].
	super layoutChanged.! !

!XpfUserStoryTimelineMorph methodsFor: 'accessing' stamp: 'cs 3/11/2009 17:38'!
model: anXpfUserStoryCollection

	model := anXpfUserStoryCollection.
	self createUserInterface.
	self model addDependent: self.! !

!XpfUserStoryTimelineMorph methodsFor: 'updating' stamp: 'cs 3/11/2009 17:19'!
update: anObject

	super update: anObject.
	self removeAllMorphs.
	self createUserInterface.! !

XpfRestTest subclass: #XpfModelToProxyTest
	instanceVariableNames: 'proxy'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Tests'!

!XpfModelToProxyTest methodsFor: 'as yet unclassified' stamp: 'cs 3/18/2009 11:05'!
setUp
	| factory |
	super setUp.
	factory := XpfProxyRepository fromString: self class url.
	proxy := factory getAllProjects first! !

!XpfModelToProxyTest methodsFor: 'as yet unclassified' stamp: 'topa 3/4/2009 00:34'!
testTitle

	self should: proxy title = testProject title.
	
	proxy userStories with: testProject userStories do: 
		[:proxyUS :realUS |  self should: proxyUS title = realUS title].! !

XpfRestTest subclass: #XpfProxyTest
	instanceVariableNames: 'projectProxy userStoryProxy'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Tests'!

!XpfProxyTest methodsFor: 'as yet unclassified' stamp: 'cs 3/18/2009 11:10'!
setUp

	| factory |
	super setUp.
	factory := XpfProxyRepository fromString: self class url.
	projectProxy := factory getAllProjects first.
	userStoryProxy := projectProxy userStories first.! !

!XpfProxyTest methodsFor: 'as yet unclassified' stamp: 'cs 3/18/2009 11:18'!
testUpdateOnAdd

	| projectTaskCount userStoryTaskCount |
	userStoryTaskCount := testStory tasks size.
	projectTaskCount := testProject tasks size.
	userStoryProxy addNewTask: (Dictionary with: 'title' -> 'UpdateOnAddTask').
	self
		should: testStory tasks size = (userStoryTaskCount + 1);
		should: testProject tasks size = (projectTaskCount + 1);
		should: userStoryProxy tasks size = (userStoryTaskCount + 1);
		should: projectProxy tasks size = (projectTaskCount + 1).! !

XpfTestCase subclass: #XpfAdminToolTest
	instanceVariableNames: 'sut factoryMock'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Tests'!

!XpfAdminToolTest methodsFor: 'setup' stamp: 'cs 3/18/2009 11:05'!
setUp
	super setUp.
	sut := XpfAdminTool new.
	factoryMock := XpfProxyRepositoryMock new.
	sut initializeWith: factoryMock.
	sut projectList selectionIndex: 1.
	sut projectList changeModelSelection: sut projectList selectionIndex.
	sut userList selectionIndex: 1.
	sut userList changeModelSelection: sut userList selectionIndex! !

!XpfAdminToolTest methodsFor: 'tests' stamp: 'mt 3/6/2009 16:07'!
testAddDeveloperToProject
	
	sut projectList selectionIndex: 1.
	sut projectList changeModelSelection: sut projectList selectionIndex.
	
	self
		should: factoryMock getAllProjects first developers size = 0;
		should: sut projectDeveloperList getList size = 0;
		should: sut projectUserDropList listMorph getList size = 2.
	
	sut projectUserDropList listSelectionIndex: 2.
	sut projectAddDeveloperButton performAction.
	
	self
		should: factoryMock getAllProjects first developers size = 1;
		should: factoryMock getAllProjects first developers first = factoryMock getAllUsers second;
		should: sut projectDeveloperList getList size = 1;
		should: sut projectUserDropList listMorph getList size = 1.! !

!XpfAdminToolTest methodsFor: 'tests' stamp: 'cs 3/9/2009 10:35'!
testAddProject
	
	| projectCount |
	projectCount := sut model projects size.
	sut projectAddButton performAction.
	
	self
		should: sut model projects size = (projectCount + 1);
		should: sut projectList selection = 'New Project'.! !

!XpfAdminToolTest methodsFor: 'tests' stamp: 'cs 3/9/2009 10:35'!
testAddUser
	
	| userCount |
	userCount := sut model users size.
	sut userAddButton performAction.
	
	self
		should: sut model users size = (userCount + 1);
		should: sut userList selection = 'New User'.! !

!XpfAdminToolTest methodsFor: 'tests' stamp: 'mt 3/5/2009 13:43'!
testDeleteProject
	
	| projectCount projectTitle |
	projectCount := sut model projects size.
	sut projectList changeModelSelection: 1.
	projectTitle := sut projectList selection.
	sut projectDeleteButton performAction.
	
	self
		should: sut model projects size = (projectCount - 1);
		should: sut projectList selectionIndex = 1;
		shouldnt: sut projectList selection = projectTitle.! !

!XpfAdminToolTest methodsFor: 'tests' stamp: 'mt 3/5/2009 13:44'!
testDeleteUser
	
	| userCount userName |
	userCount := sut model users size.
	sut userList changeModelSelection: 1.
	userName := sut userList selection.
	sut userDeleteButton performAction.
	
	self
		should: sut model users size = (userCount - 1);
		should: sut userList selectionIndex = 1;
		shouldnt: sut userList selection = userName.! !

!XpfAdminToolTest methodsFor: 'tests' stamp: 'mt 3/4/2009 13:40'!
testEditProjectTitle
	
	sut projectTitleEntry setText: 'testEditProjectTitle'.
	sut saveProjectButton performAction.
	
	self
		should: sut projectList selection = 'testEditProjectTitle';
		should: sut model projects first title = 'testEditProjectTitle'.! !

!XpfAdminToolTest methodsFor: 'tests' stamp: 'mt 3/4/2009 14:53'!
testEditUserLogin
	
	sut userLoginEntry setText: 'testEditUserLogin'.
	sut saveUserButton performAction.
	
	self
		should: sut userList selection = sut model users first userName;
		should: sut model users first login = 'testEditUserLogin'.! !

!XpfAdminToolTest methodsFor: 'tests' stamp: 'mt 3/4/2009 14:52'!
testEditUserName
	
	sut userNameEntry setText: 'testEditUserName'.
	sut saveUserButton performAction.
	
	self
		should: sut userList selection = 'testEditUserName';
		should: sut model users first userName = 'testEditUserName'.! !

!XpfAdminToolTest methodsFor: 'tests' stamp: 'mt 3/6/2009 14:36'!
testGetAllProjects
	
	self
		should: sut projectList getList size = 2;
		should: sut projectList getList first = factoryMock getAllProjects first title;
		should: sut projectList getList second = factoryMock getAllProjects second title.! !

!XpfAdminToolTest methodsFor: 'tests' stamp: 'mt 3/5/2009 13:44'!
testGetAllUsers
	
	self
		should: sut userList getList size = 2;
		should: sut userList getList first = factoryMock getAllUsers first userName.! !

!XpfAdminToolTest methodsFor: 'tests' stamp: 'cs 3/9/2009 15:42'!
testRemoveDeveloperFromProject
	
	sut projectList selectionIndex: 2.
	sut projectList changeModelSelection: sut projectList selectionIndex.
	
	self
		should: factoryMock getAllProjects second developers size = 2;
		should: sut projectDeveloperList getList size = 2;
		should: sut projectUserDropList listMorph getList size = 0.
	
	sut projectDeveloperList selectionIndex: 1.
	sut projectDeveloperList changeModelSelection: sut projectDeveloperList selectionIndex.
	sut projectDeleteDeveloperButton performAction.
	self
		should: factoryMock getAllProjects second developers size = 1;
		should: sut projectDeveloperList getList size = 1;
		should: sut projectUserDropList listMorph getList size = 1.! !

!XpfAdminToolTest methodsFor: 'tests' stamp: 'mt 3/6/2009 14:38'!
testSelectProject
	
	sut projectList selection: factoryMock projectTitle.
	sut projectList changeModelSelection: sut projectList selectionIndex.
	
	self
		should: sut projectList selectionIndex = 2;
		should: sut projectTitleEntry text = factoryMock projectTitle;
		should: sut projectDeveloperList getList size = 2;
		should: sut projectDeveloperList getList first = factoryMock getAllUsers first userName;
		should: sut projectDeveloperList getList second = factoryMock getAllUsers second userName.
		! !

!XpfAdminToolTest methodsFor: 'tests' stamp: 'mt 3/6/2009 13:30'!
testSelectUser
	
	sut userList selection: factoryMock userName.
	sut userList changeModelSelection: sut userList selectionIndex.
	
	self
		should: sut userList selectionIndex = 2;
		should: sut userNameEntry text = factoryMock userName;
		should: sut userLoginEntry text = factoryMock userLogin.! !

XpfTestCase subclass: #XpfClientTest
	instanceVariableNames: 'project userstory1 userstory2 sut task1'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Tests'!

!XpfClientTest methodsFor: 'running' stamp: 'topa 3/6/2009 17:16'!
setUp

	super setUp.
	self setupFixtures.
	sut := XpfClient new setProject: project.
! !

!XpfClientTest methodsFor: 'running' stamp: 'mfp 3/16/2009 13:09'!
setupFixtures

	project := XpfProject new title: 'Test Project'.
	userstory1 := XpfUserStory new
		title: 'Test User Story with long title.';
		explanation: 'This is the explanantion of a user story.'.
	userstory2 := XpfUserStory new title: 'Test User Story'.
	task1 := XpfTask new 
		title: 'Test Task';
		explanation: 'This is the explanantion of a task.'.
	project
		addUserStory: userstory1;
		addUserStory: userstory2.
	userstory1 addTask: task1.! !

!XpfClientTest methodsFor: 'running' stamp: 'mt 3/12/2009 13:39'!
tearDown

	project
		removeUserStory: userstory1;
		removeUserStory: userstory2.
		
	super tearDown.! !

!XpfClientTest methodsFor: 'tests' stamp: 'mt 3/13/2009 16:25'!
testAddTask

	| sut2 |
	sut2 := XpfUserStoryDetailWindow forUserStory: userstory1.

	self 
		should: sut2 taskList content submorphs size = 1;
		should: (sut2 taskList content submorphs first isKindOf: XpfTaskMorph);
		should: userstory1 tasks size = 1.

	sut2 addTask.
		
	self
		should: sut2 taskList content submorphs size = 2;
		should: (sut2 taskList content submorphs first isKindOf: XpfTaskMorph);
		should: (sut2 taskList content submorphs second isKindOf: XpfTaskMorph);
		should: userstory1 tasks size = 2.! !

!XpfClientTest methodsFor: 'tests' stamp: 'cs 3/11/2009 14:43'!
testAddUSMorphsToProjectMorph
	| usMorphCount projectMorph |
	projectMorph := XpfUserStoryPoolMorph new.
	usMorphCount := projectMorph userStorySubmorphs size.
	projectMorph 
		addUserStoryMorph: (XpfUserStoryMorph forUserStory: userstory1).
	self should: projectMorph userStorySubmorphs size = (usMorphCount + 1)! !

!XpfClientTest methodsFor: 'tests' stamp: 'cs 3/11/2009 15:04'!
testAddUserStory
	
	| userStoryCount |
	userStoryCount := sut model userStories size.
	sut userStoryPool userStoryAddMorph performAction.
	
	self should: sut model userStories size = (userStoryCount + 1).! !

!XpfClientTest methodsFor: 'tests' stamp: 'topa 3/11/2009 15:14'!
testDeleteUserStory
	
	| userStoryCount userStory |
	userStoryCount := sut model userStories size.
	userStory := sut model userStories first.
	sut userStoryPool userStoryDeleteMorph performActionWith: userStory.
	
	self should: sut model userStories size = (userStoryCount - 1).! !

!XpfClientTest methodsFor: 'tests' stamp: 'topa 3/4/2009 00:32'!
testProjectTitleDisplay

 	self should: sut label = project printString.! !

!XpfClientTest methodsFor: 'tests' stamp: 'cs 3/11/2009 17:31'!
testUserStorySubmorphs
	| sut2 |
	sut2 := XpfUserStoryPoolMorph forUserStories: project userStories.
	self should: sut2 userStorySubmorphs size = project userStories size.
	sut2 userStorySubmorphs 
		do: [:usMorph | self should: (project userStories includes: usMorph model)]! !

!XpfClientTest methodsFor: 'tests' stamp: 'mfp 3/18/2009 17:33'!
testUserStoryTextContent

	| sut2 titleMorph |
	sut2 := XpfUserStoryMorph forUserStory: userstory2.
	self should: sut2 submorphCount > 0.
	
	titleMorph := (sut2 submorphs detect: [:submorph |
			submorph isXpfTitleContent and: [submorph title getText asString = ('{1}' format: {userstory2 title})]]) title.
	self
		shouldnt: titleMorph isNil;
	 	should: titleMorph width <= XpfTitleContent defaultExtent x.! !

XpfTestCase subclass: #XpfLoginTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Tests'!

!XpfLoginTest methodsFor: 'tests' stamp: 'SR 3/10/2009 18:01'!
testLoginDialog

	| dlg |
	dlg := XpfLogin new.
	
	dlg urlEntry setText: 'https://example.com'.
	dlg loginEntry setText: 'random.guy@web.de'.
	dlg passwordEntry setText: 'secret'.
	
	dlg connectButton performAction.
	
	self
		should: dlg result = 'https://random.guy%40web.de:secret@example.com/'! !

XpfTestCase subclass: #XpfProjectChooserTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Tests'!

!XpfProjectChooserTest methodsFor: 'tests' stamp: 'SR 3/10/2009 14:19'!
testChooserDialog

	| liste sut |
	liste := {XpfProject new title:'1'. XpfProject new title: '2'}.
	sut := XpfProjectChooser new.
	sut model projects: liste.
	sut model projectsModel selectionIndex: 1.
	sut okButton performAction.
	
	self
		should: sut result = (liste at: 1).! !

Object subclass: #XpfAdminToolModel
	instanceVariableNames: 'projects currentProjectIndex users currentUserIndex currentProjectCandidateIndex currentProjectDeveloperIndex reposistory'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Models'!

!XpfAdminToolModel class methodsFor: 'as yet unclassified' stamp: 'mt 3/16/2009 11:29'!
newWithRepository: aRepository

	^ self new repository: aRepository! !

!XpfAdminToolModel methodsFor: 'updating' stamp: 'cs 3/9/2009 15:46'!
addDeveloperToProject

	self currentProject developers add: 
		(self currentProjectCandidates at: self currentProjectCandidateIndex).
			
	self currentProjectCandidateIndex: 0.
			
	self
		changed: #allProjectDeveloperNames;
		changed: #hasCurrentProjectCandidateIndex;
		changed: #allProjectCandidateNames;
		changed: #hasCurrentProjectCandidates.! !

!XpfAdminToolModel methodsFor: 'projects' stamp: 'mt 3/16/2009 14:17'!
addProject
	| newProject |
	newProject := reposistory 
				addProject: (Dictionary newFrom: {  ('title' -> 'New Project')}).
	projects := nil.
	self
		changed: #allProjectTitles;
		changed: #hasProjects;
		currentProjectIndex: (self indexOfProject: newProject);
		changed: #hasCurrentProject! !

!XpfAdminToolModel methodsFor: 'users' stamp: 'mt 3/16/2009 14:17'!
addUser
	| newUser |
	newUser := reposistory 
				addUser: (Dictionary newFrom: { 
								('userName' -> 'New User').
								('login' -> 'new.user@email.de').
								('password' -> nil)}).
	users := nil.
	self
		changed: #allUserNames;
		changed: #hasUsers;
		currentUserIndex: (self indexOfUser: newUser);
		changed: #hasCurrentUser;
		changed: #allProjectCandidateNames;
		changed: #allProjectDeveloperNames;
		changed: #hasCurrentProjectCandidates;
		changed: #hasCurrentProjectDevelopers! !

!XpfAdminToolModel methodsFor: 'projects' stamp: 'cs 3/9/2009 10:50'!
allProjectCandidateNames

	^ self currentProjectCandidates collect: [:user | user userName]! !

!XpfAdminToolModel methodsFor: 'projects' stamp: 'mt 3/6/2009 15:48'!
allProjectDeveloperNames

	^ self currentProjectDevelopers collect: [:user | user userName]! !

!XpfAdminToolModel methodsFor: 'projects' stamp: 'mt 3/3/2009 17:04'!
allProjectTitles

	^ self projects collect: [:project | project title]! !

!XpfAdminToolModel methodsFor: 'users' stamp: 'cs 3/9/2009 10:20'!
allUserNames

	^ self users collect: [:user | user userName]! !

!XpfAdminToolModel methodsFor: 'updating' stamp: 'mt 3/6/2009 13:40'!
changePassword: aDialog

	| newPassword |
	newPassword := UITheme current 
		textEntryIn: aDialog
		text: ('Enter new password for ''{1}''' format: {self currentUserName})
		title: 'Change Password'
		entryText: ''.
				
	newPassword ifNil: [^ self].
	
	self currentUserPassword: newPassword! !

!XpfAdminToolModel methodsFor: 'projects' stamp: 'cs 3/9/2009 15:36'!
currentProject

	^ self projects at: self currentProjectIndex! !

!XpfAdminToolModel methodsFor: 'accessing' stamp: 'cs 3/9/2009 15:48'!
currentProjectCandidateIndex

	^ currentProjectCandidateIndex! !

!XpfAdminToolModel methodsFor: 'accessing' stamp: 'mt 3/6/2009 16:38'!
currentProjectCandidateIndex: anObject

	currentProjectCandidateIndex := anObject.
	self
		changed: #currentProjectCandidateIndex;
		changed: #hasCurrentProjectCandidateIndex.! !

!XpfAdminToolModel methodsFor: 'projects' stamp: 'cs 3/9/2009 15:49'!
currentProjectCandidates

	self hasCurrentProject ifFalse: [^ #()].
	
	^ self users reject: [:user | 
		self currentProject developers anySatisfy: [:dev | dev id = user id]]! !

!XpfAdminToolModel methodsFor: 'accessing' stamp: 'cs 3/9/2009 15:48'!
currentProjectDeveloperIndex

	^ currentProjectDeveloperIndex! !

!XpfAdminToolModel methodsFor: 'accessing' stamp: 'cs 3/9/2009 15:45'!
currentProjectDeveloperIndex: anObject

	currentProjectDeveloperIndex := anObject.
	self changed: #currentProjectDeveloperIndex.
	self changed: #hasCurrentProjectDeveloperIndex.! !

!XpfAdminToolModel methodsFor: 'projects' stamp: 'cs 3/9/2009 15:49'!
currentProjectDevelopers

	self hasCurrentProject ifFalse: [^ #()].
	^ self currentProject developers ! !

!XpfAdminToolModel methodsFor: 'projects' stamp: 'topa 3/4/2009 00:23'!
currentProjectIndex

	^ currentProjectIndex! !

!XpfAdminToolModel methodsFor: 'projects' stamp: 'mt 3/6/2009 16:34'!
currentProjectIndex: anObject

	currentProjectIndex := anObject.
	self
		changed: #hasCurrentProject;
		changed: #currentProjectIndex;
		changed: #currentProjectTitle;
		changed: #allProjectCandidateNames;
		changed: #allProjectDeveloperNames;
		changed: #hasCurrentProjectCandidates;
		changed: #hasCurrentProjectDevelopers.! !

!XpfAdminToolModel methodsFor: 'projects' stamp: 'mt 3/6/2009 16:22'!
currentProjectTitle

	^ self hasCurrentProject
		ifTrue: [self allProjectTitles at: self currentProjectIndex]
		ifFalse: []! !

!XpfAdminToolModel methodsFor: 'projects' stamp: 'cs 3/9/2009 15:50'!
currentProjectTitle: aString

	self currentProject title: aString.
	self
		changed: #currentProjectTitle;
		changed: #allProjectTitles.! !

!XpfAdminToolModel methodsFor: 'users' stamp: 'cs 3/9/2009 15:37'!
currentUser

	^ self users at: self currentUserIndex! !

!XpfAdminToolModel methodsFor: 'users' stamp: 'mt 3/4/2009 12:59'!
currentUserIndex
	^ currentUserIndex! !

!XpfAdminToolModel methodsFor: 'users' stamp: 'mt 3/6/2009 16:34'!
currentUserIndex: anObject

	currentUserIndex := anObject.
	self
		changed: #hasCurrentUser;
		changed: #currentUserIndex;
		changed: #currentUserName;
		changed: #currentUserLogin.! !

!XpfAdminToolModel methodsFor: 'users' stamp: 'cs 3/9/2009 16:04'!
currentUserLogin

	^ self hasCurrentUser
		ifTrue: [self currentUser login]
		ifFalse: []! !

!XpfAdminToolModel methodsFor: 'users' stamp: 'mt 3/4/2009 14:46'!
currentUserLogin: aString

	(self users at: self currentUserIndex) login: aString.
	self changed: #currentUserLogin.! !

!XpfAdminToolModel methodsFor: 'users' stamp: 'mt 3/4/2009 13:36'!
currentUserName

	^ self allUserNames at: self currentUserIndex ifAbsent: []! !

!XpfAdminToolModel methodsFor: 'users' stamp: 'mt 3/12/2009 12:34'!
currentUserName: aString

	self currentUser userName: aString.
	
	self flag: #temporary. projects := nil.
	
	self
		changed: #currentUserName;
		changed: #allUserNames;
		changed: #allProjectCandidateNames;
		changed: #allProjectDeveloperNames.! !

!XpfAdminToolModel methodsFor: 'users' stamp: 'mt 3/6/2009 13:32'!
currentUserPassword: aString

	(self users at: self currentUserIndex) password: aString.! !

!XpfAdminToolModel methodsFor: 'updating' stamp: 'cs 3/9/2009 15:42'!
deleteDeveloper

	self currentProject developers remove: 
		(self currentProjectDevelopers at: self currentProjectDeveloperIndex).
			
	self currentProjectDeveloperIndex: (self currentProjectDeveloperIndex > self currentProject developers size 
			ifTrue: [self currentProject developers size] 
			ifFalse: [self currentProjectDeveloperIndex]).
			
	self
		changed: #allProjectDeveloperNames;
		changed: #hasCurrentProjectCandidateIndex;
		changed: #allProjectCandidateNames;
		changed: #hasCurrentProjectCandidates.! !

!XpfAdminToolModel methodsFor: 'projects' stamp: 'cs 3/9/2009 16:00'!
deleteProject

	self currentProject delete.
	projects := nil. "invalidate local projects"
	self
		changed: #allProjectTitles;
		changed: #hasProjects;
		currentProjectIndex: (self currentProjectIndex > self projects size 
			ifTrue: [self projects size] 
			ifFalse: [self currentProjectIndex]);
		changed: #hasCurrentProject.! !

!XpfAdminToolModel methodsFor: 'users' stamp: 'cs 3/9/2009 16:01'!
deleteUser

	self currentUser delete.
	users := nil. "invalidate local users"
	self
		changed: #allUserNames;
		changed: #hasUsers;
		currentUserIndex: (self currentUserIndex > self users size 
			ifTrue: [self users size] 
			ifFalse: [self currentUserIndex]);
		changed: #hasCurrentUser;
		changed: #allProjectCandidateNames;
		changed: #allProjectDeveloperNames;
		changed: #hasCurrentProjectCandidates;
		changed: #hasCurrentProjectDevelopers.! !

!XpfAdminToolModel methodsFor: 'projects' stamp: 'mt 3/5/2009 13:35'!
hasCurrentProject

	^ self currentProjectIndex notNil and: 
		[(self currentProjectIndex > 0) & (self currentProjectIndex <= self projects size)]! !

!XpfAdminToolModel methodsFor: 'projects' stamp: 'mt 3/12/2009 10:50'!
hasCurrentProjectCandidateIndex

	^ self currentProjectCandidateIndex notNil and: 
		[(self currentProjectCandidateIndex > 0) & (self currentProjectCandidateIndex <= self currentProjectCandidates size)]! !

!XpfAdminToolModel methodsFor: 'projects' stamp: 'mt 3/6/2009 15:38'!
hasCurrentProjectCandidates

	^ self currentProjectCandidates isEmpty not! !

!XpfAdminToolModel methodsFor: 'projects' stamp: 'cs 3/9/2009 16:01'!
hasCurrentProjectDeveloperIndex

	^ self hasCurrentProject and:
		[self currentProjectDeveloperIndex notNil and: 
		[(self currentProjectDeveloperIndex > 0) &
		(self currentProjectDeveloperIndex <= self currentProject developers size)]]! !

!XpfAdminToolModel methodsFor: 'projects' stamp: 'mt 3/6/2009 15:38'!
hasCurrentProjectDevelopers

	^ self currentProjectDevelopers isEmpty not! !

!XpfAdminToolModel methodsFor: 'users' stamp: 'mt 3/5/2009 13:49'!
hasCurrentUser

	^ self currentUserIndex notNil and: 
		[(self currentUserIndex > 0) & (self currentUserIndex <= self users size)]! !

!XpfAdminToolModel methodsFor: 'projects' stamp: 'mt 3/5/2009 14:05'!
hasProjects

	^ self projects isEmpty not! !

!XpfAdminToolModel methodsFor: 'users' stamp: 'mt 3/5/2009 14:05'!
hasUsers

	^ self users isEmpty not! !

!XpfAdminToolModel methodsFor: 'projects' stamp: 'cs 3/9/2009 10:30'!
indexOfProject: aProject
	"returns the index of the specified project in the displayed list of projects"

	^ self projects indexOf: (self projects detect: [:each | each id = aProject id])! !

!XpfAdminToolModel methodsFor: 'users' stamp: 'cs 3/9/2009 10:28'!
indexOfUser: aUser
	"returns the index of the specified user in the displayed list of users"

	^ self users indexOf: (self users detect: [:each | each id = aUser id])! !

!XpfAdminToolModel methodsFor: 'initialization' stamp: 'mt 3/6/2009 16:20'!
initialize

	super initialize.
	self
		currentProjectIndex: 0;
		currentUserIndex: 0;
		currentProjectCandidateIndex: 0;
		currentProjectDeveloperIndex: 0.! !

!XpfAdminToolModel methodsFor: 'projects' stamp: 'mt 3/16/2009 14:17'!
projects
	^ projects ifNil: 
			[projects := reposistory getAllProjects 
						sortBy: [:first :second | first title < second title]]! !

!XpfAdminToolModel methodsFor: 'accessing' stamp: 'mt 3/16/2009 14:17'!
repository

	^ reposistory! !

!XpfAdminToolModel methodsFor: 'accessing' stamp: 'mt 3/16/2009 14:17'!
repository: anObject

	reposistory := anObject.! !

!XpfAdminToolModel methodsFor: 'updating' stamp: 'mt 3/5/2009 14:32'!
updateUser: someEntries

	someEntries do: [:entry | entry accept]! !

!XpfAdminToolModel methodsFor: 'users' stamp: 'mt 3/16/2009 14:17'!
users
	^ users ifNil: 
			[users := reposistory getAllUsers 
						sortBy: [:first :second | first userName < second userName]]! !

Object subclass: #XpfLoginModel
	instanceVariableNames: 'url login password'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Models'!

!XpfLoginModel methodsFor: 'accessing' stamp: 'cs 3/18/2009 15:26'!
connectString

	"self password ifEmpty: [^ 'http://{1}@{2}:{3}/' format: {self login encodeForHTTP. self host. self port}]." "not allowed."
	| myUrl myStream |
	myUrl := self url asUrl.
	
	myStream := WriteStream on: ''.
	myStream nextPutAll: myUrl schemeName.
	myStream nextPutAll: '://'.
	self login ifNotNil: [
		myStream nextPutAll: self login encodeForHTTP.
		self password ifNotNil: [
			myStream nextPutAll: ':'.
			myStream nextPutAll: self password encodeForHTTP ].
		myStream nextPutAll: '@' ].
	myStream nextPutAll: myUrl authority.
	myUrl port ifNotNil: [myStream nextPut: $:; print: myUrl port].
	myUrl path do: [ :pathElem |
		myStream nextPut: $/.
		myStream nextPutAll: pathElem encodeForHTTP. ].
	myUrl query isNil ifFalse: [ 
		myStream nextPut: $?.
		myStream nextPutAll: self query. ].
	myUrl fragment isNil ifFalse: [
		myStream nextPut: $#.
		myStream nextPutAll: self fragment encodeForHTTP. ].
	^ myStream contents! !

!XpfLoginModel methodsFor: 'initialization' stamp: 'SR 3/10/2009 17:32'!
initialize

	super initialize.
	self
		url: 'http://localhost:8082/';
		login: 'admin@example.com';
		password: 'nimda'.! !

!XpfLoginModel methodsFor: 'accessing' stamp: 'topa 3/6/2009 14:53'!
login

	^ login! !

!XpfLoginModel methodsFor: 'accessing' stamp: 'topa 3/6/2009 14:53'!
login: anObject

	login := anObject.! !

!XpfLoginModel methodsFor: 'accessing' stamp: 'topa 3/6/2009 14:53'!
password

	^ password! !

!XpfLoginModel methodsFor: 'accessing' stamp: 'topa 3/6/2009 14:54'!
password: anObject

	password := anObject.! !

!XpfLoginModel methodsFor: 'accessing' stamp: 'SR 3/10/2009 17:32'!
url
	^ url! !

!XpfLoginModel methodsFor: 'accessing' stamp: 'SR 3/10/2009 17:32'!
url: anObject
	url := anObject! !

Object subclass: #XpfProjectChooserModel
	instanceVariableNames: 'projects projectsModel'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Models'!

!XpfProjectChooserModel methodsFor: 'initialization' stamp: 'SR 3/10/2009 13:58'!
initialize
	
	super initialize.
	
	projects := OrderedCollection new.
	projectsModel := ListModel new.! !

!XpfProjectChooserModel methodsFor: 'accessing' stamp: 'SR 3/10/2009 14:04'!
project

	^ (self projectsModel selectionIndex = 0)
		ifTrue: [nil]
		ifFalse: [self projects at: self projectsModel selectionIndex]! !

!XpfProjectChooserModel methodsFor: 'accessing' stamp: 'SR 3/10/2009 11:45'!
projects
	^ projects! !

!XpfProjectChooserModel methodsFor: 'accessing' stamp: 'mig 3/18/2009 16:20'!
projects: anObject
	projects := anObject.
	projectsModel list: (self projects collect: [:e | e title]).
	projectsModel list ifNotEmpty: [projectsModel selectionIndex: 1]. 
	self changed.! !

!XpfProjectChooserModel methodsFor: 'accessing' stamp: 'SR 3/10/2009 13:58'!
projectsModel
	^ projectsModel! !

Object subclass: #XpfProxyObjectMock
	instanceVariableNames: 'entity relatives'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Tests'!

XpfProxyObjectMock class
	instanceVariableNames: 'nextId'!

XpfProxyObjectMock class
	instanceVariableNames: 'nextId'!

!XpfProxyObjectMock class methodsFor: 'instance creation' stamp: 'mt 3/6/2009 16:10'!
newProjectMock

	^ self new entity: (XpfProject new title: 'Born to be deleted'; id: self nextId)! !

!XpfProxyObjectMock class methodsFor: 'instance creation' stamp: 'mt 3/6/2009 16:10'!
newUserMock

	^ self new entity: (XpfUser new userName: 'Mr. Lemming'; id: self nextId)! !

!XpfProxyObjectMock class methodsFor: 'accessing' stamp: 'mt 3/6/2009 16:11'!
nextId

	nextId ifNil: [nextId := 0].
	nextId := nextId + 1.
	^ nextId! !

!XpfProxyObjectMock class methodsFor: 'accessing' stamp: 'mt 3/6/2009 16:10'!
nextId: anObject
	nextId := anObject! !

!XpfProxyObjectMock methodsFor: 'deleting' stamp: 'mt 3/5/2009 12:04'!
delete

	relatives remove: self! !

!XpfProxyObjectMock methodsFor: 'error handling' stamp: 'mt 3/5/2009 12:16'!
doesNotUnderstand: aMessage

	| result |
	result := entity perform: aMessage selector withArguments: aMessage arguments.
	^ result = entity ifTrue: [self] ifFalse: [result]! !

!XpfProxyObjectMock methodsFor: 'accessing' stamp: 'mt 3/5/2009 12:05'!
entity
	^ entity! !

!XpfProxyObjectMock methodsFor: 'accessing' stamp: 'mt 3/5/2009 12:05'!
entity: anObject
	entity := anObject! !

!XpfProxyObjectMock methodsFor: 'accessing' stamp: 'mt 3/5/2009 12:05'!
relatives
	^ relatives! !

!XpfProxyObjectMock methodsFor: 'accessing' stamp: 'mt 3/5/2009 12:05'!
relatives: anObject
	relatives := anObject! !

Object subclass: #XpfProxyRepositoryMock
	instanceVariableNames: 'projects users'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Tests'!

!XpfProxyRepositoryMock methodsFor: 'add-remove' stamp: 'mt 3/5/2009 12:14'!
addProject: aDictionary

	^ projects add: (XpfProxyObjectMock new
		entity: (XpfProject newFrom: aDictionary);
		relatives: projects)! !

!XpfProxyRepositoryMock methodsFor: 'add-remove' stamp: 'mt 3/5/2009 10:55'!
addUser: aDictionary

	^ users add: (XpfUser newFrom: aDictionary)! !

!XpfProxyRepositoryMock methodsFor: 'accessing' stamp: 'mt 3/5/2009 09:55'!
getAllProjects

	^ projects! !

!XpfProxyRepositoryMock methodsFor: 'accessing' stamp: 'mt 3/5/2009 10:54'!
getAllUsers

	^ users! !

!XpfProxyRepositoryMock methodsFor: 'initialization' stamp: 'mt 3/6/2009 14:32'!
initialize

	super initialize.
	projects := {XpfProxyObjectMock newProjectMock. XpfProxyObjectMock newProjectMock title: self projectTitle} asOrderedCollection.
	users := {XpfProxyObjectMock newUserMock. XpfProxyObjectMock newUserMock login: self userLogin; userName: self userName; password: self userPassword} asOrderedCollection.
	
	projects do: [:project | project relatives: projects].
	users do: [:user | 
		user relatives: users. 
		projects second developers add: user].
! !

!XpfProxyRepositoryMock methodsFor: 'accessing' stamp: 'mt 3/4/2009 13:39'!
projectTitle

	^ 'test project'! !

!XpfProxyRepositoryMock methodsFor: 'accessing' stamp: 'mt 3/4/2009 11:17'!
userLogin

	^ 'random.guy'! !

!XpfProxyRepositoryMock methodsFor: 'accessing' stamp: 'mt 3/4/2009 12:17'!
userName

	^ 'Random Guy'! !

!XpfProxyRepositoryMock methodsFor: 'accessing' stamp: 'mt 3/6/2009 13:26'!
userPassword

	^ 'topsecret'! !

PanelMorph subclass: #XpfEntityMorphContent
	instanceVariableNames: 'model inEditMode'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

XpfEntityMorphContent subclass: #XpfEditButtons
	instanceVariableNames: 'acceptButton cancelButton'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfEditButtons class methodsFor: 'as yet unclassified' stamp: 'mfp 3/18/2009 15:06'!
defaultExtent
	
	^ 2@2! !

!XpfEditButtons methodsFor: 'accessing' stamp: 'mfp 3/18/2009 15:11'!
acceptButton

	acceptButton ifNil: [
		acceptButton := UITheme current
			newButtonIn: self
			for:  self
			getState: nil
			action: #changed:
			arguments: #(accepted)
			getEnabled: nil
			label: 'Accept'
			help: 'Clicking this button accepts the changes.'
		].
	^ acceptButton! !

!XpfEditButtons methodsFor: 'accessing' stamp: 'mfp 3/18/2009 14:39'!
acceptButton: anObject
	acceptButton := anObject! !

!XpfEditButtons methodsFor: 'accessing' stamp: 'mfp 3/18/2009 15:59'!
cancelButton

	cancelButton ifNil: [
		cancelButton := UITheme current
			newButtonIn: self
			for:  self
			getState: nil
			action: #changed:
			arguments: #(cancelled)
			getEnabled: nil
			label: 'Cancel'
			help: 'Clicking this button discards the changes.'
		].
	^ cancelButton! !

!XpfEditButtons methodsFor: 'accessing' stamp: 'mfp 3/18/2009 14:39'!
cancelButton: anObject
	cancelButton := anObject! !

!XpfEditButtons methodsFor: 'as yet unclassified' stamp: 'mfp 3/18/2009 16:04'!
initialize

	super initialize.
	
	self
		hResizing: #spaceFill;
		vResizing: #shrinkWrap;
		addMorph: (UITheme current newRowIn: self for: { 
		(UITheme current newToolSpacerIn: self) hResizing: #spaceFill; vResizing: #rigid. 
		self acceptButton. 
		self cancelButton}) ! !

!XpfEntityMorphContent class methodsFor: 'as yet unclassified' stamp: 'mfp 3/17/2009 16:48'!
defaultExtent

	self subclassResponsibility.! !

!XpfEntityMorphContent class methodsFor: 'as yet unclassified' stamp: 'mfp 3/17/2009 16:23'!
forModel: anXpfEntity

	^ self basicNew
		model: anXpfEntity;
		initialize! !

!XpfEntityMorphContent methodsFor: 'accessing' stamp: 'mfp 3/18/2009 15:30'!
accept! !

!XpfEntityMorphContent methodsFor: 'accessing' stamp: 'mfp 3/18/2009 16:08'!
cancel! !

!XpfEntityMorphContent methodsFor: 'accessing' stamp: 'mfp 3/18/2009 14:52'!
inEditMode
	^ inEditMode! !

!XpfEntityMorphContent methodsFor: 'accessing' stamp: 'mfp 3/18/2009 14:52'!
inEditMode: anObject
	inEditMode := anObject! !

!XpfEntityMorphContent methodsFor: 'as yet unclassified' stamp: 'mfp 3/18/2009 15:38'!
initialize

	super initialize.
	self 
		inEditMode: false;
		layoutPolicy: TableLayout new;
		hResizing: #rigid;
		vResizing: #rigid;
		extent: self class defaultExtent;
		fillStyle: Color transparent.! !

!XpfEntityMorphContent methodsFor: 'accessing' stamp: 'mfp 3/17/2009 15:09'!
model

	^ model! !

!XpfEntityMorphContent methodsFor: 'accessing' stamp: 'mfp 3/17/2009 16:45'!
model: anXpfEntity

	self model ifNotNil: [self model removeDependent: self].
	model := anXpfEntity.
	self model addDependent: self.
	
	self update.! !

!XpfEntityMorphContent methodsFor: 'as yet unclassified' stamp: 'mfp 3/18/2009 15:56'!
toggleEditMode

	self
		inEditMode: (self inEditMode not);
		update.
	! !

!XpfEntityMorphContent methodsFor: 'accessing' stamp: 'mfp 3/18/2009 15:30'!
update! !

XpfEntityMorphContent subclass: #XpfTitleContent
	instanceVariableNames: 'title'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfTitleContent class methodsFor: 'defaults' stamp: 'mfp 3/18/2009 14:27'!
defaultExtent

	^ 200@100! !

!XpfTitleContent methodsFor: 'as yet unclassified' stamp: 'mfp 3/18/2009 15:15'!
accept

	self title accept.! !

!XpfTitleContent methodsFor: 'as yet unclassified' stamp: 'mfp 3/18/2009 16:08'!
cancel

	self title cancel.! !

!XpfTitleContent methodsFor: 'as yet unclassified' stamp: 'mfp 3/18/2009 16:04'!
initialize

	super initialize.
	self
		addMorph: self title;
		update. "lock first"! !

!XpfTitleContent methodsFor: 'as yet unclassified' stamp: 'mfp 3/18/2009 17:27'!
isXpfTitleContent

	^ true! !

!XpfTitleContent methodsFor: 'accessing' stamp: 'mfp 3/18/2009 14:32'!
title

	title ifNil: [
		title := (UITheme current
		newTextEditorIn:  self
		for: self model
		getText: #title
		setText: #title:
		getEnabled: nil) spaceFillWeight: 2].
	^ title! !

!XpfTitleContent methodsFor: 'accessing' stamp: 'mfp 3/17/2009 15:21'!
title: anObject

	title := anObject.! !

!XpfTitleContent methodsFor: 'as yet unclassified' stamp: 'mfp 3/18/2009 15:57'!
update
	super update.
	
	(self inEditMode notNil and: [self inEditMode])
		ifTrue: [ self title enable ]
		ifFalse: [ self title disable ] 
! !

XpfEntityMorphContent subclass: #XpfTitleExplanationContent
	instanceVariableNames: 'title explanation'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfTitleExplanationContent class methodsFor: 'as yet unclassified' stamp: 'mfp 3/18/2009 14:27'!
defaultExtent

	^ 200@200! !

!XpfTitleExplanationContent methodsFor: 'as yet unclassified' stamp: 'mfp 3/17/2009 17:05'!
accept
	
	self explanation accept.
	self title accept.! !

!XpfTitleExplanationContent methodsFor: 'as yet unclassified' stamp: 'mfp 3/18/2009 18:22'!
cancel

	self title cancel.
	self explanation cancel.! !

!XpfTitleExplanationContent methodsFor: 'accessing' stamp: 'mfp 3/17/2009 17:00'!
explanation

	explanation ifNil: [
		explanation := (UITheme current
		newTextEditorIn: self
		for: self model
		getText: #explanation
		setText: #explanation:
		getEnabled: nil) spaceFillWeight: 2; alwaysAccept: true].
	^ explanation! !

!XpfTitleExplanationContent methodsFor: 'accessing' stamp: 'mfp 3/17/2009 16:51'!
explanation: anObject

	explanation := anObject.! !

!XpfTitleExplanationContent methodsFor: 'as yet unclassified' stamp: 'mfp 3/18/2009 18:20'!
initialize

	super initialize.
	self
		initializeUI;
		update.! !

!XpfTitleExplanationContent methodsFor: 'as yet unclassified' stamp: 'mfp 3/17/2009 17:03'!
initializeUI

	self addMorph: (UITheme current newColumnIn: self for: {
		self title.
		self explanation}).! !

!XpfTitleExplanationContent methodsFor: 'accessing' stamp: 'mfp 3/17/2009 17:02'!
title

	title ifNil: [
		title := (UITheme current
		newTextEntryIn: self
		for: self model
		get: #title
		set: #title:
		class: String
		getEnabled: nil
		help: 'Enter a short descriptive title for this user story.') maxLength: 100].
	^ title! !

!XpfTitleExplanationContent methodsFor: 'accessing' stamp: 'mfp 3/17/2009 16:51'!
title: anObject

	title := anObject.! !

!XpfTitleExplanationContent methodsFor: 'as yet unclassified' stamp: 'mfp 3/18/2009 18:19'!
update
	super update.
	
	(self inEditMode notNil and: [self inEditMode])
		ifTrue: [ self title enable. self explanation enable ]
		ifFalse: [ self title disable. self explanation disable ] ! !

XpfEntityMorphContent subclass: #XpfZoomButtons
	instanceVariableNames: 'zoomInButton zoomOutButton'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfZoomButtons class methodsFor: 'as yet unclassified' stamp: 'mfp 3/18/2009 18:15'!
defaultExtent
	
	^ 2@2! !

!XpfZoomButtons methodsFor: 'as yet unclassified' stamp: 'mfp 3/18/2009 16:15'!
initialize

	super initialize.
	
	self
		hResizing: #spaceFill;
		vResizing: #shrinkWrap;
		addMorph: (UITheme current newRowIn: self for: { 
		self zoomInButton. 
		self zoomOutButton.
		(UITheme current newToolSpacerIn: self) hResizing: #spaceFill; vResizing: #rigid. }) ! !

!XpfZoomButtons methodsFor: 'accessing' stamp: 'mfp 3/18/2009 16:15'!
zoomInButton

	zoomInButton ifNil: [
		zoomInButton := UITheme current
			newButtonIn: self
			for:  self
			getState: nil
			action: #changed:
			arguments: #(zoomIn)
			getEnabled: nil
			label: 'More'
			help: ''
		].
	^ zoomInButton! !

!XpfZoomButtons methodsFor: 'accessing' stamp: 'mfp 3/18/2009 16:13'!
zoomInButton: anObject
	zoomInButton := anObject! !

!XpfZoomButtons methodsFor: 'accessing' stamp: 'mfp 3/18/2009 16:15'!
zoomOutButton

	zoomOutButton ifNil: [
		zoomOutButton := UITheme current
			newButtonIn: self
			for:  self
			getState: nil
			action: #changed:
			arguments: #(zoomOut)
			getEnabled: nil
			label: 'Less'
			help: ''
		].
	^ zoomOutButton! !

!XpfZoomButtons methodsFor: 'accessing' stamp: 'mfp 3/18/2009 16:13'!
zoomOutButton: anObject
	zoomOutButton := anObject! !

BorderedMorph subclass: #XpfEntityMorph
	instanceVariableNames: 'model currentContent inEditMode buttonContent zoomContent'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfEntityMorph class methodsFor: 'as yet unclassified' stamp: 'mt 3/13/2009 13:49'!
defaultColor

	^ self subclassResponsibility! !

!XpfEntityMorph methodsFor: 'accessing' stamp: 'mfp 3/18/2009 15:28'!
buttonContent

	buttonContent ifNil: [self buttonContent:
		(XpfEditButtons new
			addDependent: self;
			yourself)].
	^ buttonContent! !

!XpfEntityMorph methodsFor: 'accessing' stamp: 'mfp 3/18/2009 15:26'!
buttonContent: anObject

	buttonContent := anObject! !

!XpfEntityMorph methodsFor: 'event handling' stamp: 'mfp 3/18/2009 17:13'!
click: evt! !

!XpfEntityMorph methodsFor: 'accessing' stamp: 'mfp 3/18/2009 18:14'!
currentContent

	^ currentContent! !

!XpfEntityMorph methodsFor: 'accessing' stamp: 'mfp 3/18/2009 18:14'!
currentContent: anObject

	currentContent := anObject.! !

!XpfEntityMorph methodsFor: 'event handling' stamp: 'mfp 3/18/2009 17:12'!
doubleClick: evt

	self inEditMode ifFalse: [self toggleEditMode].

"	self currentContent = #titleContent ifTrue: [^ self useDetailContent].
	self currentContent = #detailContent ifTrue: [^ self useTitleContent]."
	
	! !

!XpfEntityMorph methodsFor: 'event handling' stamp: 'mfp 3/18/2009 17:12'!
firstClickTimedOut: evt

	evt redButtonPressed ifTrue: [
		evt hand grabMorph: self].! !

!XpfEntityMorph methodsFor: 'event handling' stamp: 'mfp 3/18/2009 17:08'!
handlesMouseDown: evt

	^ true! !

!XpfEntityMorph methodsFor: 'accessing' stamp: 'mfp 3/18/2009 15:00'!
inEditMode
	^ inEditMode! !

!XpfEntityMorph methodsFor: 'accessing' stamp: 'mfp 3/18/2009 15:00'!
inEditMode: anObject
	inEditMode := anObject! !

!XpfEntityMorph methodsFor: 'initialization' stamp: 'mfp 3/18/2009 17:06'!
initialize

	super initialize.
	self
		inEditMode: false;
		layoutPolicy: TableLayout new;
		hResizing: #shrinkWrap;
		vResizing: #shrinkWrap;
		borderWidth: 1;
		addDropShadow;
		layoutInset: 10;
		color: self class defaultColor;
		enableDragNDrop;
		useTitleContent.! !

!XpfEntityMorph methodsFor: 'accessing' stamp: 'mt 3/13/2009 13:54'!
model

	^ model! !

!XpfEntityMorph methodsFor: 'accessing' stamp: 'mfp 3/17/2009 16:45'!
model: anXpfEntity

	self model ifNotNil: [self model removeDependent: self].
	model := anXpfEntity.
	self model addDependent: self.
	self updateContentModel.
	! !

!XpfEntityMorph methodsFor: 'as yet unclassified' stamp: 'mfp 3/18/2009 17:13'!
mouseDown: evt
	"Do nothing upon mouse-down except inform the hand to watch for a 
	double-click; wait until an ensuing click:, doubleClick:, or drag: 
	message gets dispatched"
	
	evt hand
		waitForClicksOrDrag: self
		event: evt
		selectors: {#click:. #doubleClick:. #firstClickTimedOut:. nil}
		threshold: 5.! !

!XpfEntityMorph methodsFor: 'as yet unclassified' stamp: 'mfp 3/18/2009 16:02'!
toggleEditMode
	
	self submorphs do: [:contentMorph | 
		contentMorph toggleEditMode].
	
	self inEditMode: self inEditMode not.
	
	self inEditMode 
		ifTrue: [self addMorphBack: self buttonContent]
		ifFalse: [self removeMorph: self buttonContent]! !

!XpfEntityMorph methodsFor: 'event handling' stamp: 'mfp 3/18/2009 18:18'!
update: aSymbol
		
	aSymbol = #accepted
		ifTrue: [self submorphs do: [:contentMorph | contentMorph accept]].
		
	aSymbol = #cancelled
		ifTrue: [self submorphs do: [:contentMorph | contentMorph cancel]].		

	(aSymbol = #accepted) | (aSymbol = #cancelled)
		ifTrue: [self toggleEditMode].
		
	aSymbol = #zoomIn
		ifTrue: [self useDetailContent].
	
	aSymbol = #zoomOut
		ifTrue: [self useTitleContent].
	
	super update: aSymbol.

	! !

!XpfEntityMorph methodsFor: 'as yet unclassified' stamp: 'mfp 3/17/2009 16:08'!
updateContentModel

	(self model isNil | self submorphs isNil) ifTrue: [^ self].
	self submorphs do: [:contentMorph | contentMorph model: self model].! !

!XpfEntityMorph methodsFor: 'content handling' stamp: 'mfp 3/18/2009 18:15'!
useTitleContent

	self submorphs ifNotNil: [self submorphs do: [:contentMorph | contentMorph accept]].
	
	self
		removeAllMorphs;
		addMorph: (self zoomContent);
		addMorphBack: (XpfTitleContent forModel: self model);
		currentContent: #titleContent.! !

!XpfEntityMorph methodsFor: 'accessing' stamp: 'mfp 3/18/2009 18:14'!
zoomContent

	zoomContent ifNil: [self zoomContent:
		(XpfZoomButtons new
			addDependent: self;
			yourself)].
	^ zoomContent! !

!XpfEntityMorph methodsFor: 'accessing' stamp: 'mfp 3/18/2009 18:14'!
zoomContent: anObject

	zoomContent := anObject.! !

XpfEntityMorph subclass: #XpfTaskMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfTaskMorph class methodsFor: 'defaults' stamp: 'mt 3/13/2009 11:08'!
defaultColor

	^ Color white! !

!XpfTaskMorph class methodsFor: 'initialize-release' stamp: 'mfp 3/17/2009 16:05'!
forTask: anXpfTask

	^ self basicNew
		model: anXpfTask;
		initialize! !

!XpfTaskMorph methodsFor: 'testing' stamp: 'mt 3/13/2009 14:50'!
isTaskMorph

	^ true! !

XpfEntityMorph subclass: #XpfUserStoryMorph
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfUserStoryMorph class methodsFor: 'defaults' stamp: 'mfp 3/17/2009 15:34'!
defaultColor
	
	^	Color white.! !

!XpfUserStoryMorph class methodsFor: 'initialize-release' stamp: 'mfp 3/17/2009 16:04'!
forUserStory: anXpfUserStory

	^ self basicNew
		model: anXpfUserStory;
		initialize! !

!XpfUserStoryMorph methodsFor: 'as yet unclassified' stamp: 'mfp 3/18/2009 17:12'!
click: evt

	evt yellowButtonPressed ifTrue: [
		self openContextPopupMenu.
		evt wasHandled: true].! !

!XpfUserStoryMorph methodsFor: 'updating' stamp: 'mfp 3/18/2009 17:16'!
initialize

	super initialize.
	self update: nil.! !

!XpfUserStoryMorph methodsFor: 'testing' stamp: 'topa 3/4/2009 00:21'!
isUserStoryMorph

	^ true! !

!XpfUserStoryMorph methodsFor: 'as yet unclassified' stamp: 'mfp 3/18/2009 16:58'!
openContextPopupMenu

	| menu |
	menu := MenuMorph new.
	menu addTitle: 'Set Color'.
	#(#gray #red #yellow #green #cyan #blue #magenta #brown) do: [:currentColor | 
		menu add: currentColor asString capitalized target: self selector: #setColor: argument: currentColor].
	menu addLine.
	menu add: 'Clear' target: self selector: #setColor: argument: #white.
	menu popUpInWorld.
! !

!XpfUserStoryMorph methodsFor: 'as yet unclassified' stamp: 'mfp 3/18/2009 16:58'!
setColor: aColorSymbol

	self model color: aColorSymbol asString.
! !

!XpfUserStoryMorph methodsFor: 'updating' stamp: 'mfp 3/18/2009 17:13'!
update: aSymbol

	self model color ifNotNil: [
		self color: (Color colorFrom: self model color asSymbol) muchLighter].
	
	super update: aSymbol.! !

!XpfUserStoryMorph methodsFor: 'content handling' stamp: 'mfp 3/18/2009 18:15'!
useDetailContent

	self submorphs ifNotNil: [self submorphs do: [:contentMorph | contentMorph accept]].
	
	self
		removeAllMorphs;
		addMorph: self zoomContent;
		addMorphBack: (XpfTitleExplanationContent forModel: self model);
		currentContent: #detailContent.! !

!XpfUserStoryMorph methodsFor: 'dropping/grabbing' stamp: 'mfp 3/18/2009 16:58'!
wantsToBeDroppedInto: aMorph

	^ aMorph acceptsUserStories! !

BorderedMorph subclass: #XpfTaskDetailWindow
	instanceVariableNames: 'model explanationText titleText taskList addTaskButton'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfTaskDetailWindow class methodsFor: 'instance creation' stamp: 'mfp 3/16/2009 13:04'!
forTask: anXpfTask

	^ self new initializeWith: anXpfTask! !

!XpfTaskDetailWindow methodsFor: 'actions' stamp: 'mfp 3/16/2009 13:04'!
addTask

	self model addNewTask: (Dictionary newFrom: {
		'title' -> nil.
		'explanation' -> nil.
		'timeEstimated' -> nil}).
	self taskList updateList.! !

!XpfTaskDetailWindow methodsFor: 'accessing' stamp: 'mfp 3/16/2009 13:04'!
addTaskButton
	^ addTaskButton! !

!XpfTaskDetailWindow methodsFor: 'accessing' stamp: 'mfp 3/16/2009 13:04'!
addTaskButton: anObject
	addTaskButton := anObject! !

!XpfTaskDetailWindow methodsFor: 'actions' stamp: 'mfp 3/16/2009 13:04'!
cancel
	
	self changed: #detailsClosed.
	self delete.! !

!XpfTaskDetailWindow methodsFor: 'initialization' stamp: 'mfp 3/16/2009 13:04'!
createAddTaskButton

	self addTaskButton: (UITheme current 
		newButtonIn: self
		for: self
		getState: nil
		action: #addTask
		arguments: nil
		getEnabled: #enabled
		label: 'Add Task'
		help: '...').
	^ self addTaskButton! !

!XpfTaskDetailWindow methodsFor: 'initialization' stamp: 'mfp 3/16/2009 13:04'!
createButtonRowFor: aUserStory

	^ UITheme current newRowIn: self for: {
		self createLabel: '#', aUserStory id asString.
		(UITheme current newToolSpacerIn: self) hResizing: #spaceFill.
		self createOkButton.
		self createCancelButton.
	}! !

!XpfTaskDetailWindow methodsFor: 'initialization' stamp: 'mfp 3/16/2009 13:04'!
createCancelButton

	^ (UITheme current 
		newButtonIn: self
		for: self
		getState: nil
		action: #cancel
		arguments: nil
		getEnabled: #enabled
		label: 'Cancel'
		help: 'Discard your changes and close this card.')! !

!XpfTaskDetailWindow methodsFor: 'initialization' stamp: 'mfp 3/16/2009 13:04'!
createExplanationTextFor: aUserStory

	self explanationText: ((UITheme current
		newTextEditorIn: self
		for: aUserStory
		getText: #explanation
		setText: #explanation:
		getEnabled: nil) spaceFillWeight: 2).
	^ self explanationText alwaysAccept: true
! !

!XpfTaskDetailWindow methodsFor: 'initialization' stamp: 'mfp 3/16/2009 13:04'!
createLabel: aString

	^ UITheme current
		newLabelIn: self
		label: aString! !

!XpfTaskDetailWindow methodsFor: 'initialization' stamp: 'mfp 3/16/2009 13:04'!
createOkButton

	^ (UITheme current 
		newButtonIn: self
		for: self
		getState: nil
		action: #ok
		arguments: nil
		getEnabled: #enabled
		label: 'Ok'
		help: 'Save changes.')! !

!XpfTaskDetailWindow methodsFor: 'initialization' stamp: 'mfp 3/16/2009 13:04'!
createTaskListFor: aUserStory

	self taskList: (XpfTaskListMorph forUserStory: aUserStory).
	^ self taskList.! !

!XpfTaskDetailWindow methodsFor: 'initialization' stamp: 'mfp 3/16/2009 13:04'!
createTitleTextFor: aUserStory

	self titleText: ((UITheme current
		newTextEntryIn: self
		for: aUserStory
		get: #title
		set: #title:
		class: String
		getEnabled: nil
		help: 'Enter a short descriptive title for this user story.') 
	maxLength: 100).
	^ self titleText! !

!XpfTaskDetailWindow methodsFor: 'accessing' stamp: 'mfp 3/16/2009 13:04'!
explanationText

	^ explanationText! !

!XpfTaskDetailWindow methodsFor: 'accessing' stamp: 'mfp 3/16/2009 13:04'!
explanationText: anObject

	explanationText := anObject.! !

!XpfTaskDetailWindow methodsFor: 'initialization' stamp: 'mfp 3/16/2009 13:04'!
initializeWith: aUserStory

	| col |	
	col := UITheme current newColumnIn: self for: {
		self createTitleTextFor: aUserStory.
		self createExplanationTextFor: aUserStory.
		self createTaskListFor: aUserStory.
		self createAddTaskButton.
		self createButtonRowFor: aUserStory}.
		
	self
		layoutPolicy: TableLayout new;
		addMorph: col;
		extent: 250@300;
		vResizing: #shrinkWrap;
		hResizing: #shrinkWrap;
		borderWidth: 1;
		layoutInset: 10;
		useRoundedCorners;
		addDropShadow;
		color: XpfUserStoryMorph defaultColor;
		model: aUserStory.! !

!XpfTaskDetailWindow methodsFor: 'accessing' stamp: 'mfp 3/16/2009 13:04'!
model

	^ model! !

!XpfTaskDetailWindow methodsFor: 'accessing' stamp: 'mfp 3/16/2009 13:04'!
model: anXpfUserStory

	model := anXpfUserStory.! !

!XpfTaskDetailWindow methodsFor: 'actions' stamp: 'mfp 3/16/2009 13:04'!
ok

	self titleText accept.
	self explanationText accept.	
	self
		changed: #detailsClosed;
		delete.
	! !

!XpfTaskDetailWindow methodsFor: 'accessing' stamp: 'mfp 3/16/2009 13:04'!
taskList
	^ taskList! !

!XpfTaskDetailWindow methodsFor: 'accessing' stamp: 'mfp 3/16/2009 13:04'!
taskList: anObject
	taskList := anObject! !

!XpfTaskDetailWindow methodsFor: 'accessing' stamp: 'mfp 3/16/2009 13:04'!
titleText

	^ titleText! !

!XpfTaskDetailWindow methodsFor: 'accessing' stamp: 'mfp 3/16/2009 13:04'!
titleText: anObject

	titleText := anObject.! !

!XpfTaskDetailWindow methodsFor: 'dropping/grabbing' stamp: 'mfp 3/16/2009 13:04'!
wantsToBeDroppedInto: aMorph

	self changed: #detailsMoved.
	^ super wantsToBeDroppedInto: aMorph
	! !

BorderedMorph subclass: #XpfUserStoryAddMorph
	instanceVariableNames: 'model'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfUserStoryAddMorph commentStamp: 'topa 3/9/2009 15:16' prior: 0!
I am a Morph that should behave somehow like a Button, yet are embeddable into
a PasteUpMorph.!

!XpfUserStoryAddMorph class methodsFor: 'defaults' stamp: 'topa 3/9/2009 15:13'!
defaultBorderColor

	^ Color darkGray! !

!XpfUserStoryAddMorph class methodsFor: 'defaults' stamp: 'topa 3/11/2009 14:22'!
defaultColor

	^ Color tan! !

!XpfUserStoryAddMorph class methodsFor: 'defaults' stamp: 'topa 3/9/2009 15:13'!
defaultExtent

	^ 100@60 ! !

!XpfUserStoryAddMorph class methodsFor: 'defaults' stamp: 'topa 3/11/2009 14:27'!
defaultShadowColor

	^ Color darkGray! !

!XpfUserStoryAddMorph class methodsFor: 'defaults' stamp: 'topa 3/9/2009 17:01'!
emptyUserStory

	^ Dictionary newFrom:	{ 
			'id' -> nil.
			'title' -> nil.
			'priority' -> nil.
			'timeEstimated' -> nil.
			'timeActual' -> nil.
			'explanation' -> nil}! !

!XpfUserStoryAddMorph class methodsFor: 'initialize-release' stamp: 'cs 3/11/2009 17:57'!
forProjects: anXpfProject

	^ self new model: anXpfProject! !

!XpfUserStoryAddMorph methodsFor: 'event handling' stamp: 'topa 3/11/2009 14:00'!
handlesMouseDown: evt

	self enabled ifTrue:
		[evt hand waitForClicksOrDrag: self event: evt].
	^ true! !

!XpfUserStoryAddMorph methodsFor: 'initialization' stamp: 'topa 3/11/2009 14:26'!
initialize

	super initialize.
	self
		extent: self class defaultExtent;
		color: self class defaultColor;
		borderColor: self class defaultBorderColor;
		borderWidth: 1;
		useRoundedCorners;
		addDropShadow; shadowOffset: 5@5; shadowColor: self class defaultShadowColor.! !

!XpfUserStoryAddMorph methodsFor: 'accessing' stamp: 'topa 3/11/2009 15:20'!
model

	^ model! !

!XpfUserStoryAddMorph methodsFor: 'accessing' stamp: 'topa 3/11/2009 15:20'!
model: anObject

	model := anObject.! !

!XpfUserStoryAddMorph methodsFor: 'event handling' stamp: 'cs 3/18/2009 15:28'!
mouseDown: evt
	
	^ self performAction openInHand! !

!XpfUserStoryAddMorph methodsFor: 'event handling' stamp: 'cs 3/18/2009 15:28'!
performAction
	"for Button behavior"

	^ (XpfUserStoryMorph forUserStory: 
		(self model addNewUserStory: self class emptyUserStory))
		changed: #newModel! !

BorderedMorph subclass: #XpfUserStoryDetailWindow
	instanceVariableNames: 'model explanationText titleText taskList addTaskButton'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfUserStoryDetailWindow class methodsFor: 'instance creation' stamp: 'topa 3/3/2009 20:51'!
forUserStory: aUserStory

	^ self new initializeWith: aUserStory! !

!XpfUserStoryDetailWindow methodsFor: 'actions' stamp: 'mt 3/13/2009 15:29'!
addTask

	self model addNewTask: (Dictionary newFrom: {
		'title' -> nil.
		'explanation' -> nil.
		'timeEstimated' -> nil}).
	self taskList updateList.! !

!XpfUserStoryDetailWindow methodsFor: 'accessing' stamp: 'mt 3/13/2009 14:54'!
addTaskButton
	^ addTaskButton! !

!XpfUserStoryDetailWindow methodsFor: 'accessing' stamp: 'mt 3/13/2009 14:54'!
addTaskButton: anObject
	addTaskButton := anObject! !

!XpfUserStoryDetailWindow methodsFor: 'actions' stamp: 'mt 3/12/2009 17:11'!
cancel
	
	self changed: #detailsClosed.
	self delete.! !

!XpfUserStoryDetailWindow methodsFor: 'initialization' stamp: 'mt 3/13/2009 15:11'!
createAddTaskButton

	self addTaskButton: (UITheme current 
		newButtonIn: self
		for: self
		getState: nil
		action: #addTask
		arguments: nil
		getEnabled: #enabled
		label: 'Add Task'
		help: '...').
	^ self addTaskButton! !

!XpfUserStoryDetailWindow methodsFor: 'initialization' stamp: 'mt 3/12/2009 17:04'!
createButtonRowFor: aUserStory

	^ UITheme current newRowIn: self for: {
		self createLabel: '#', aUserStory id asString.
		(UITheme current newToolSpacerIn: self) hResizing: #spaceFill.
		self createOkButton.
		self createCancelButton.
	}! !

!XpfUserStoryDetailWindow methodsFor: 'initialization' stamp: 'mt 3/12/2009 17:07'!
createCancelButton

	^ (UITheme current 
		newButtonIn: self
		for: self
		getState: nil
		action: #cancel
		arguments: nil
		getEnabled: #enabled
		label: 'Cancel'
		help: 'Discard your changes and close this card.')! !

!XpfUserStoryDetailWindow methodsFor: 'initialization' stamp: 'mt 3/13/2009 12:59'!
createExplanationTextFor: aUserStory

	self explanationText: ((UITheme current
		newTextEditorIn: self
		for: aUserStory
		getText: #explanation
		setText: #explanation:
		getEnabled: nil) spaceFillWeight: 2).
	^ self explanationText alwaysAccept: true
! !

!XpfUserStoryDetailWindow methodsFor: 'initialization' stamp: 'mt 3/12/2009 16:45'!
createLabel: aString

	^ UITheme current
		newLabelIn: self
		label: aString! !

!XpfUserStoryDetailWindow methodsFor: 'initialization' stamp: 'mt 3/12/2009 17:08'!
createOkButton

	^ (UITheme current 
		newButtonIn: self
		for: self
		getState: nil
		action: #ok
		arguments: nil
		getEnabled: #enabled
		label: 'Ok'
		help: 'Save changes.')! !

!XpfUserStoryDetailWindow methodsFor: 'initialization' stamp: 'cs 3/18/2009 15:29'!
createTaskListFor: aUserStory

	self taskList: (XpfTaskListMorph forUserStory: aUserStory).
	^ self taskList! !

!XpfUserStoryDetailWindow methodsFor: 'initialization' stamp: 'topa 3/4/2009 00:06'!
createTitleTextFor: aUserStory

	self titleText: ((UITheme current
		newTextEntryIn: self
		for: aUserStory
		get: #title
		set: #title:
		class: String
		getEnabled: nil
		help: 'Enter a short descriptive title for this user story.') 
	maxLength: 100).
	^ self titleText! !

!XpfUserStoryDetailWindow methodsFor: 'accessing' stamp: 'topa 3/4/2009 00:06'!
explanationText

	^ explanationText! !

!XpfUserStoryDetailWindow methodsFor: 'accessing' stamp: 'topa 3/4/2009 00:06'!
explanationText: anObject

	explanationText := anObject.! !

!XpfUserStoryDetailWindow methodsFor: 'initialization' stamp: 'mfp 3/17/2009 10:56'!
initializeWith: aUserStory

	| col |	
	col := UITheme current newColumnIn: self for: {
		self createTitleTextFor: aUserStory.
		self createExplanationTextFor: aUserStory.
		self createTaskListFor: aUserStory.
		self createAddTaskButton.
		self createButtonRowFor: aUserStory}.
		
	self
		layoutPolicy: TableLayout new;
		addMorph: col;
		extent: 250@300;
		vResizing: #shrinkWrap;
		hResizing: #shrinkWrap;
		borderWidth: 1;
		layoutInset: 10;
		addDropShadow;
		color: XpfUserStoryMorph defaultColor;
		model: aUserStory.! !

!XpfUserStoryDetailWindow methodsFor: 'accessing' stamp: 'mt 3/13/2009 15:02'!
model

	^ model! !

!XpfUserStoryDetailWindow methodsFor: 'accessing' stamp: 'mt 3/13/2009 15:02'!
model: anXpfUserStory

	model := anXpfUserStory.! !

!XpfUserStoryDetailWindow methodsFor: 'actions' stamp: 'mt 3/12/2009 17:11'!
ok

	self titleText accept.
	self explanationText accept.	
	self
		changed: #detailsClosed;
		delete.
	! !

!XpfUserStoryDetailWindow methodsFor: 'accessing' stamp: 'mt 3/13/2009 11:24'!
taskList
	^ taskList! !

!XpfUserStoryDetailWindow methodsFor: 'accessing' stamp: 'mt 3/13/2009 11:24'!
taskList: anObject
	taskList := anObject! !

!XpfUserStoryDetailWindow methodsFor: 'accessing' stamp: 'topa 3/4/2009 00:07'!
titleText

	^ titleText! !

!XpfUserStoryDetailWindow methodsFor: 'accessing' stamp: 'topa 3/4/2009 00:07'!
titleText: anObject

	titleText := anObject.! !

!XpfUserStoryDetailWindow methodsFor: 'dropping/grabbing' stamp: 'mt 3/12/2009 17:26'!
wantsToBeDroppedInto: aMorph

	self changed: #detailsMoved.
	^ super wantsToBeDroppedInto: aMorph
	! !

RestProxyObject subclass: #XpfProxyObject
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Helpers'!

!XpfProxyObject methodsFor: 'add-remove' stamp: 'cs 3/18/2009 11:35'!
addNewTask: aDictionary

	| task |
	task := super addNewTask: aDictionary.
	"if I am an userstory then tell the project to reload its tasks"
	(self includesProperty: 'project') ifTrue: [self project tasks reload].! !

RestProxyRepository subclass: #XpfProxyRepository
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Helpers'!

!XpfProxyRepository methodsFor: 'add-remove' stamp: 'cs 3/18/2009 11:55'!
addProject: aProject 

	^ self getAllProjects addNew: aProject! !

!XpfProxyRepository methodsFor: 'add-remove' stamp: 'cs 3/18/2009 11:56'!
addUser: aUser 

	^ self getAllUsers addNew: aUser! !

!XpfProxyRepository methodsFor: 'accessing' stamp: 'mig 3/13/2009 15:58'!
getAllProjects

	^ self getCollection: '/projects/'! !

!XpfProxyRepository methodsFor: 'accessing' stamp: 'mig 3/13/2009 15:58'!
getAllUsers

	^ self getCollection: '/users/'! !

!XpfProxyRepository methodsFor: 'private' stamp: 'cs 3/18/2009 11:29'!
proxyObjectClass

	^ XpfProxyObject! !

PluggableSystemWindow subclass: #XpfClient
	instanceVariableNames: 'userStoryPool userStoryTimeline'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfClient class methodsFor: 'defaults' stamp: 'cs 3/11/2009 18:19'!
defaultHeight

	^ 260! !

!XpfClient class methodsFor: 'defaults' stamp: 'topa 3/11/2009 15:57'!
defaultWidth

	^ 560! !

!XpfClient class methodsFor: 'user interface' stamp: 'cs 3/18/2009 11:05'!
open
	| instance connectionString response factory user project projectChooser |
	instance := self new.
	connectionString := (instance openModal: XpfLogin new) result.
	connectionString ifNil: [^ self].
	[response := RestSocket get: connectionString] on: NetworkError
		do: 
			[:e | 
			UITheme current 
				alertIn: instance
				text: e messageText
				title: 'Network Error'.
			^ self].
	response responseCode = 401 
		ifTrue: 
			[UITheme current 
				alertIn: instance
				text: 'You are not authorized to access any resource on the server.'
				title: 'Connection failed'.
			^ self].
	factory := XpfProxyRepository fromString: connectionString.
	user := factory 
				getObject: (RestSocket get: connectionString , '/info') content.
	projectChooser := XpfProjectChooser new.
	projectChooser model projects: user projects.
	project := (instance openModal: projectChooser) result.
	project ifNil: [^ self].
	^ (instance setProject: project) openInWorld! !

!XpfClient methodsFor: 'as yet unclassified' stamp: 'SR 3/18/2009 11:24'!
delete
	self userStoryPool saveUserStoryPosition.
	super delete.! !

!XpfClient methodsFor: 'initialization' stamp: 'SR 3/18/2009 11:07'!
initialize

	super initialize.	
	self
		initializeUserInterface;
		width: self class defaultWidth;
		height: self class defaultHeight.! !

!XpfClient methodsFor: 'initialization' stamp: 'mt 3/13/2009 10:55'!
initializeUserInterface

	self flag: #NeedsRefactoring.
	self
		"layoutPolicy: TableLayout new;"
		userStoryTimeline: XpfUserStoryTimelineMorph newWithScrollBars;
		userStoryPool: XpfUserStoryPoolMorph new;
		addMorph: (UITheme current newColumnIn: self for:
			{self userStoryTimeline. self userStoryPool}) 
		fullFrame: (LayoutFrame fractions: (0 @ 0 corner: 1 @ 1)
					offsets: (0 @ 0 corner: 0 @ 0)).! !

!XpfClient methodsFor: 'accessing' stamp: 'cs 3/11/2009 17:59'!
model: anXpfProject

	super model: anXpfProject.
	self userStoryPool model: anXpfProject userStories.
	self userStoryPool userStoryAddMorph model: anXpfProject.
	self userStoryTimeline scroller firstSubmorph model: anXpfProject userStories.
! !

!XpfClient methodsFor: 'accessing' stamp: 'cs 3/11/2009 16:06'!
setProject: anXpfProject

	self
		model: anXpfProject;
		getLabelSelector: #title;
		width: self class defaultWidth;
		height: self class defaultHeight.! !

!XpfClient methodsFor: 'accessing' stamp: 'cs 3/11/2009 14:42'!
userStoryPool
	^ userStoryPool! !

!XpfClient methodsFor: 'accessing' stamp: 'cs 3/11/2009 14:42'!
userStoryPool: anObject
	userStoryPool := anObject! !

!XpfClient methodsFor: 'accessing' stamp: 'cs 3/11/2009 14:41'!
userStoryTimeline
	^ userStoryTimeline! !

!XpfClient methodsFor: 'accessing' stamp: 'cs 3/11/2009 14:41'!
userStoryTimeline: anObject
	userStoryTimeline := anObject! !

ImageMorph subclass: #XpfUserStoryDeleteMorph
	instanceVariableNames: 'model'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Xpf-Client-Morphs'!

!XpfUserStoryDeleteMorph class methodsFor: 'initialize-release' stamp: 'cs 3/11/2009 18:14'!
forUserStories: anXpfUserStoryCollection

	^ self new model: anXpfUserStoryCollection! !

!XpfUserStoryDeleteMorph methodsFor: 'layout' stamp: 'topa 3/11/2009 15:51'!
acceptDroppingMorph: aMorph event: evt 

	aMorph isUserStoryMorph 
		ifTrue: [self performActionWith: aMorph model. aMorph delete].	
! !

!XpfUserStoryDeleteMorph methodsFor: 'testing' stamp: 'topa 3/11/2009 15:46'!
acceptsUserStories

	^ true! !

!XpfUserStoryDeleteMorph methodsFor: 'initialization' stamp: 'topa 3/11/2009 15:30'!
initialize

	super initialize.
	self image: TrashCanMorph initializeTrashPicOn.! !

!XpfUserStoryDeleteMorph methodsFor: 'accessing' stamp: 'cs 3/11/2009 18:13'!
model
	^ model! !

!XpfUserStoryDeleteMorph methodsFor: 'accessing' stamp: 'cs 3/11/2009 18:13'!
model: anObject
	model := anObject! !

!XpfUserStoryDeleteMorph methodsFor: 'event handling' stamp: 'cs 3/11/2009 18:13'!
performActionWith: anXpfUserStory

	self model remove: anXpfUserStory.! !

!XpfUserStoryDeleteMorph methodsFor: 'dropping/grabbing' stamp: 'topa 3/11/2009 15:40'!
wantsDroppedMorph: aMorph event: evt

	^ aMorph isUserStoryMorph! !

!Morph methodsFor: '*xpf-client' stamp: 'cs 3/10/2009 16:13'!
acceptsUserStories

	^ false! !

!Morph methodsFor: '*xpf-client' stamp: 'mt 3/13/2009 14:49'!
isTaskMorph

	^ false! !

!Morph methodsFor: '*xpf-client' stamp: 'topa 3/3/2009 23:50'!
isUserStoryMorph

	^ false! !
